from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.affect_report_data import AffectReportData


T = TypeVar("T", bound="FlawReportData")


@_attrs_define
class FlawReportData(OSIDBModel):
    """
    Attributes:
        cve_id (Union[None, Unset, str]):
        affects (Union[Unset, list['AffectReportData']]):
    """

    cve_id: Union[None, Unset, str] = UNSET
    affects: Union[Unset, list["AffectReportData"]] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        cve_id: Union[None, Unset, str]
        if isinstance(self.cve_id, Unset):
            cve_id = UNSET
        else:
            cve_id = self.cve_id

        affects: Union[Unset, list[dict[str, Any]]] = UNSET
        if not isinstance(self.affects, Unset):
            affects = []
            for affects_item_data in self.affects:
                affects_item: dict[str, Any] = UNSET
                if not isinstance(affects_item_data, Unset):
                    affects_item = affects_item_data.to_dict()

                affects.append(affects_item)

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(cve_id, Unset):
            field_dict["cve_id"] = cve_id
        if not isinstance(affects, Unset):
            field_dict["affects"] = affects

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.affect_report_data import AffectReportData

        d = src_dict.copy()

        def _parse_cve_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cve_id = _parse_cve_id(d.pop("cve_id", UNSET))

        affects = []
        _affects = d.pop("affects", UNSET)
        for affects_item_data in _affects or []:
            _affects_item = affects_item_data
            affects_item: AffectReportData
            if isinstance(_affects_item, Unset):
                affects_item = UNSET
            else:
                affects_item = AffectReportData.from_dict(_affects_item)

            affects.append(affects_item)

        flaw_report_data = cls(
            cve_id=cve_id,
            affects=affects,
        )

        flaw_report_data.additional_properties = d
        return flaw_report_data

    @staticmethod
    def get_fields():
        return {
            "cve_id": Union[None, str],
            "affects": list["AffectReportData"],
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""Contains all the data models used in inputs/outputs"""

from .affect import Affect
from .affect_bulk_post_put_response import AffectBulkPostPutResponse
from .affect_bulk_put_request import AffectBulkPutRequest
from .affect_cvss import AffectCVSS
from .affect_cvss_post_request import AffectCVSSPostRequest
from .affect_cvss_put_request import AffectCVSSPutRequest
from .affect_cvss_request import AffectCVSSRequest
from .affect_post_request import AffectPostRequest
from .affect_report_data import AffectReportData
from .affect_request import AffectRequest
from .affectedness_enum import AffectednessEnum
from .alert import Alert
from .alert_type_enum import AlertTypeEnum
from .audit import Audit
from .audit_request import AuditRequest
from .auth_token_create_response_200 import AuthTokenCreateResponse200
from .auth_token_refresh_create_response_200 import AuthTokenRefreshCreateResponse200
from .auth_token_retrieve_response_200 import AuthTokenRetrieveResponse200
from .auth_token_verify_create_response_200 import AuthTokenVerifyCreateResponse200
from .blank_enum import BlankEnum
from .collectors_api_v1_status_retrieve_response_200 import (
    CollectorsApiV1StatusRetrieveResponse200,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItem,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_data import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemData,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_error_type_0 import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemErrorType0,
)
from .collectors_api_v1_status_retrieve_response_200_collectors_item_state import (
    CollectorsApiV1StatusRetrieveResponse200CollectorsItemState,
)
from .collectors_healthy_retrieve_response_200 import (
    CollectorsHealthyRetrieveResponse200,
)
from .collectors_retrieve_response_200 import CollectorsRetrieveResponse200
from .comment import Comment
from .comment_request import CommentRequest
from .cvss_version_enum import CvssVersionEnum
from .epss import EPSS
from .erratum import Erratum
from .exploit_only_report_data import ExploitOnlyReportData
from .exploit_only_report_data_source_enum import ExploitOnlyReportDataSourceEnum
from .exploits_api_v1_collect_update_response_200 import (
    ExploitsApiV1CollectUpdateResponse200,
)
from .exploits_api_v1_cve_map_retrieve_response_200 import (
    ExploitsApiV1CveMapRetrieveResponse200,
)
from .exploits_api_v1_cve_map_retrieve_response_200_cves import (
    ExploitsApiV1CveMapRetrieveResponse200Cves,
)
from .exploits_api_v1_epss_list_response_200 import ExploitsApiV1EpssListResponse200
from .exploits_api_v1_flaw_data_list_response_200 import (
    ExploitsApiV1FlawDataListResponse200,
)
from .exploits_api_v1_report_data_list_response_200 import (
    ExploitsApiV1ReportDataListResponse200,
)
from .exploits_api_v1_report_date_retrieve_response_200 import (
    ExploitsApiV1ReportDateRetrieveResponse200,
)
from .exploits_api_v1_report_date_retrieve_response_200_action_required_item import (
    ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem,
)
from .exploits_api_v1_report_date_retrieve_response_200_no_action_item import (
    ExploitsApiV1ReportDateRetrieveResponse200NoActionItem,
)
from .exploits_api_v1_report_date_retrieve_response_200_not_relevant_item import (
    ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem,
)
from .exploits_api_v1_report_explanations_retrieve_response_200 import (
    ExploitsApiV1ReportExplanationsRetrieveResponse200,
)
from .exploits_api_v1_report_explanations_retrieve_response_200_explanations_item import (
    ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem,
)
from .exploits_api_v1_report_pending_retrieve_response_200 import (
    ExploitsApiV1ReportPendingRetrieveResponse200,
)
from .exploits_api_v1_report_pending_retrieve_response_200_pending_actions_item import (
    ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem,
)
from .exploits_api_v1_status_retrieve_response_200 import (
    ExploitsApiV1StatusRetrieveResponse200,
)
from .exploits_api_v1_supported_products_list_response_200 import (
    ExploitsApiV1SupportedProductsListResponse200,
)
from .flaw import Flaw
from .flaw_acknowledgment import FlawAcknowledgment
from .flaw_acknowledgment_post_request import FlawAcknowledgmentPostRequest
from .flaw_acknowledgment_put_request import FlawAcknowledgmentPutRequest
from .flaw_acknowledgment_request import FlawAcknowledgmentRequest
from .flaw_classification import FlawClassification
from .flaw_classification_state import FlawClassificationState
from .flaw_collaborator import FlawCollaborator
from .flaw_collaborator_post_request import FlawCollaboratorPostRequest
from .flaw_collaborator_request import FlawCollaboratorRequest
from .flaw_comment import FlawComment
from .flaw_comment_post_request import FlawCommentPostRequest
from .flaw_cvss import FlawCVSS
from .flaw_cvss_post_request import FlawCVSSPostRequest
from .flaw_cvss_put_request import FlawCVSSPutRequest
from .flaw_cvss_request import FlawCVSSRequest
from .flaw_label import FlawLabel
from .flaw_package_version import FlawPackageVersion
from .flaw_package_version_post_request import FlawPackageVersionPostRequest
from .flaw_package_version_put_request import FlawPackageVersionPutRequest
from .flaw_post_request import FlawPostRequest
from .flaw_reference import FlawReference
from .flaw_reference_post_request import FlawReferencePostRequest
from .flaw_reference_put_request import FlawReferencePutRequest
from .flaw_reference_request import FlawReferenceRequest
from .flaw_reference_type import FlawReferenceType
from .flaw_report_data import FlawReportData
from .flaw_request import FlawRequest
from .flaw_uuid_list_request import FlawUUIDListRequest
from .flaw_version import FlawVersion
from .flaw_version_request import FlawVersionRequest
from .impact_enum import ImpactEnum
from .issuer_enum import IssuerEnum
from .major_incident_state_enum import MajorIncidentStateEnum
from .maturity_preliminary_enum import MaturityPreliminaryEnum
from .module_component import ModuleComponent
from .nist_cvss_validation_enum import NistCvssValidationEnum
from .not_affected_justification_enum import NotAffectedJustificationEnum
from .osidb_api_v1_affects_bulk_create_response_200 import (
    OsidbApiV1AffectsBulkCreateResponse200,
)
from .osidb_api_v1_affects_bulk_destroy_response_200 import (
    OsidbApiV1AffectsBulkDestroyResponse200,
)
from .osidb_api_v1_affects_bulk_update_response_200 import (
    OsidbApiV1AffectsBulkUpdateResponse200,
)
from .osidb_api_v1_affects_create_response_201 import OsidbApiV1AffectsCreateResponse201
from .osidb_api_v1_affects_cvss_scores_create_response_201 import (
    OsidbApiV1AffectsCvssScoresCreateResponse201,
)
from .osidb_api_v1_affects_cvss_scores_destroy_response_200 import (
    OsidbApiV1AffectsCvssScoresDestroyResponse200,
)
from .osidb_api_v1_affects_cvss_scores_list_issuer import (
    OsidbApiV1AffectsCvssScoresListIssuer,
)
from .osidb_api_v1_affects_cvss_scores_list_response_200 import (
    OsidbApiV1AffectsCvssScoresListResponse200,
)
from .osidb_api_v1_affects_cvss_scores_retrieve_response_200 import (
    OsidbApiV1AffectsCvssScoresRetrieveResponse200,
)
from .osidb_api_v1_affects_cvss_scores_update_response_200 import (
    OsidbApiV1AffectsCvssScoresUpdateResponse200,
)
from .osidb_api_v1_affects_destroy_response_200 import (
    OsidbApiV1AffectsDestroyResponse200,
)
from .osidb_api_v1_affects_list_affectedness import OsidbApiV1AffectsListAffectedness
from .osidb_api_v1_affects_list_cvss_scores_issuer import (
    OsidbApiV1AffectsListCvssScoresIssuer,
)
from .osidb_api_v1_affects_list_flaw_impact import OsidbApiV1AffectsListFlawImpact
from .osidb_api_v1_affects_list_flaw_source import OsidbApiV1AffectsListFlawSource
from .osidb_api_v1_affects_list_impact import OsidbApiV1AffectsListImpact
from .osidb_api_v1_affects_list_order_item import OsidbApiV1AffectsListOrderItem
from .osidb_api_v1_affects_list_resolution import OsidbApiV1AffectsListResolution
from .osidb_api_v1_affects_list_response_200 import OsidbApiV1AffectsListResponse200
from .osidb_api_v1_affects_list_trackers_type import OsidbApiV1AffectsListTrackersType
from .osidb_api_v1_affects_retrieve_response_200 import (
    OsidbApiV1AffectsRetrieveResponse200,
)
from .osidb_api_v1_affects_update_response_200 import OsidbApiV1AffectsUpdateResponse200
from .osidb_api_v1_alerts_list_alert_type import OsidbApiV1AlertsListAlertType
from .osidb_api_v1_alerts_list_parent_model import OsidbApiV1AlertsListParentModel
from .osidb_api_v1_alerts_list_response_200 import OsidbApiV1AlertsListResponse200
from .osidb_api_v1_alerts_retrieve_response_200 import (
    OsidbApiV1AlertsRetrieveResponse200,
)
from .osidb_api_v1_audit_list_response_200 import OsidbApiV1AuditListResponse200
from .osidb_api_v1_audit_retrieve_response_200 import OsidbApiV1AuditRetrieveResponse200
from .osidb_api_v1_audit_update_response_200 import OsidbApiV1AuditUpdateResponse200
from .osidb_api_v1_flaws_acknowledgments_create_response_201 import (
    OsidbApiV1FlawsAcknowledgmentsCreateResponse201,
)
from .osidb_api_v1_flaws_acknowledgments_destroy_response_200 import (
    OsidbApiV1FlawsAcknowledgmentsDestroyResponse200,
)
from .osidb_api_v1_flaws_acknowledgments_list_response_200 import (
    OsidbApiV1FlawsAcknowledgmentsListResponse200,
)
from .osidb_api_v1_flaws_acknowledgments_retrieve_response_200 import (
    OsidbApiV1FlawsAcknowledgmentsRetrieveResponse200,
)
from .osidb_api_v1_flaws_acknowledgments_update_response_200 import (
    OsidbApiV1FlawsAcknowledgmentsUpdateResponse200,
)
from .osidb_api_v1_flaws_comments_create_response_201 import (
    OsidbApiV1FlawsCommentsCreateResponse201,
)
from .osidb_api_v1_flaws_comments_list_response_200 import (
    OsidbApiV1FlawsCommentsListResponse200,
)
from .osidb_api_v1_flaws_comments_retrieve_response_200 import (
    OsidbApiV1FlawsCommentsRetrieveResponse200,
)
from .osidb_api_v1_flaws_create_response_201 import OsidbApiV1FlawsCreateResponse201
from .osidb_api_v1_flaws_cvss_scores_create_response_201 import (
    OsidbApiV1FlawsCvssScoresCreateResponse201,
)
from .osidb_api_v1_flaws_cvss_scores_destroy_response_200 import (
    OsidbApiV1FlawsCvssScoresDestroyResponse200,
)
from .osidb_api_v1_flaws_cvss_scores_list_issuer import (
    OsidbApiV1FlawsCvssScoresListIssuer,
)
from .osidb_api_v1_flaws_cvss_scores_list_response_200 import (
    OsidbApiV1FlawsCvssScoresListResponse200,
)
from .osidb_api_v1_flaws_cvss_scores_retrieve_response_200 import (
    OsidbApiV1FlawsCvssScoresRetrieveResponse200,
)
from .osidb_api_v1_flaws_cvss_scores_update_response_200 import (
    OsidbApiV1FlawsCvssScoresUpdateResponse200,
)
from .osidb_api_v1_flaws_labels_create_response_201 import (
    OsidbApiV1FlawsLabelsCreateResponse201,
)
from .osidb_api_v1_flaws_labels_destroy_response_204 import (
    OsidbApiV1FlawsLabelsDestroyResponse204,
)
from .osidb_api_v1_flaws_labels_list_response_200 import (
    OsidbApiV1FlawsLabelsListResponse200,
)
from .osidb_api_v1_flaws_labels_retrieve_response_200 import (
    OsidbApiV1FlawsLabelsRetrieveResponse200,
)
from .osidb_api_v1_flaws_labels_update_response_200 import (
    OsidbApiV1FlawsLabelsUpdateResponse200,
)
from .osidb_api_v1_flaws_list_affects_affectedness import (
    OsidbApiV1FlawsListAffectsAffectedness,
)
from .osidb_api_v1_flaws_list_affects_impact import OsidbApiV1FlawsListAffectsImpact
from .osidb_api_v1_flaws_list_affects_resolution import (
    OsidbApiV1FlawsListAffectsResolution,
)
from .osidb_api_v1_flaws_list_affects_trackers_type import (
    OsidbApiV1FlawsListAffectsTrackersType,
)
from .osidb_api_v1_flaws_list_cvss_scores_issuer import (
    OsidbApiV1FlawsListCvssScoresIssuer,
)
from .osidb_api_v1_flaws_list_impact import OsidbApiV1FlawsListImpact
from .osidb_api_v1_flaws_list_major_incident_state import (
    OsidbApiV1FlawsListMajorIncidentState,
)
from .osidb_api_v1_flaws_list_nist_cvss_validation import (
    OsidbApiV1FlawsListNistCvssValidation,
)
from .osidb_api_v1_flaws_list_order_item import OsidbApiV1FlawsListOrderItem
from .osidb_api_v1_flaws_list_references_type import OsidbApiV1FlawsListReferencesType
from .osidb_api_v1_flaws_list_requires_cve_description import (
    OsidbApiV1FlawsListRequiresCveDescription,
)
from .osidb_api_v1_flaws_list_response_200 import OsidbApiV1FlawsListResponse200
from .osidb_api_v1_flaws_list_source import OsidbApiV1FlawsListSource
from .osidb_api_v1_flaws_list_workflow_state_item import (
    OsidbApiV1FlawsListWorkflowStateItem,
)
from .osidb_api_v1_flaws_package_versions_create_response_201 import (
    OsidbApiV1FlawsPackageVersionsCreateResponse201,
)
from .osidb_api_v1_flaws_package_versions_destroy_response_200 import (
    OsidbApiV1FlawsPackageVersionsDestroyResponse200,
)
from .osidb_api_v1_flaws_package_versions_list_response_200 import (
    OsidbApiV1FlawsPackageVersionsListResponse200,
)
from .osidb_api_v1_flaws_package_versions_retrieve_response_200 import (
    OsidbApiV1FlawsPackageVersionsRetrieveResponse200,
)
from .osidb_api_v1_flaws_package_versions_update_response_200 import (
    OsidbApiV1FlawsPackageVersionsUpdateResponse200,
)
from .osidb_api_v1_flaws_promote_create_response_200 import (
    OsidbApiV1FlawsPromoteCreateResponse200,
)
from .osidb_api_v1_flaws_references_create_response_201 import (
    OsidbApiV1FlawsReferencesCreateResponse201,
)
from .osidb_api_v1_flaws_references_destroy_response_200 import (
    OsidbApiV1FlawsReferencesDestroyResponse200,
)
from .osidb_api_v1_flaws_references_list_response_200 import (
    OsidbApiV1FlawsReferencesListResponse200,
)
from .osidb_api_v1_flaws_references_list_type import OsidbApiV1FlawsReferencesListType
from .osidb_api_v1_flaws_references_retrieve_response_200 import (
    OsidbApiV1FlawsReferencesRetrieveResponse200,
)
from .osidb_api_v1_flaws_references_update_response_200 import (
    OsidbApiV1FlawsReferencesUpdateResponse200,
)
from .osidb_api_v1_flaws_reject_create_response_200 import (
    OsidbApiV1FlawsRejectCreateResponse200,
)
from .osidb_api_v1_flaws_retrieve_response_200 import OsidbApiV1FlawsRetrieveResponse200
from .osidb_api_v1_flaws_update_response_200 import OsidbApiV1FlawsUpdateResponse200
from .osidb_api_v1_labels_list_response_200 import OsidbApiV1LabelsListResponse200
from .osidb_api_v1_labels_retrieve_response_200 import (
    OsidbApiV1LabelsRetrieveResponse200,
)
from .osidb_api_v1_manifest_retrieve_response_200 import (
    OsidbApiV1ManifestRetrieveResponse200,
)
from .osidb_api_v1_schema_retrieve_format import OsidbApiV1SchemaRetrieveFormat
from .osidb_api_v1_schema_retrieve_lang import OsidbApiV1SchemaRetrieveLang
from .osidb_api_v1_schema_retrieve_response_200 import (
    OsidbApiV1SchemaRetrieveResponse200,
)
from .osidb_api_v1_status_retrieve_response_200 import (
    OsidbApiV1StatusRetrieveResponse200,
)
from .osidb_api_v1_status_retrieve_response_200_osidb_data import (
    OsidbApiV1StatusRetrieveResponse200OsidbData,
)
from .osidb_api_v1_status_retrieve_response_200_osidb_service import (
    OsidbApiV1StatusRetrieveResponse200OsidbService,
)
from .osidb_api_v1_trackers_create_response_201 import (
    OsidbApiV1TrackersCreateResponse201,
)
from .osidb_api_v1_trackers_list_affects_affectedness import (
    OsidbApiV1TrackersListAffectsAffectedness,
)
from .osidb_api_v1_trackers_list_affects_flaw_impact import (
    OsidbApiV1TrackersListAffectsFlawImpact,
)
from .osidb_api_v1_trackers_list_affects_flaw_source import (
    OsidbApiV1TrackersListAffectsFlawSource,
)
from .osidb_api_v1_trackers_list_affects_impact import (
    OsidbApiV1TrackersListAffectsImpact,
)
from .osidb_api_v1_trackers_list_affects_resolution import (
    OsidbApiV1TrackersListAffectsResolution,
)
from .osidb_api_v1_trackers_list_order_item import OsidbApiV1TrackersListOrderItem
from .osidb_api_v1_trackers_list_response_200 import OsidbApiV1TrackersListResponse200
from .osidb_api_v1_trackers_list_type import OsidbApiV1TrackersListType
from .osidb_api_v1_trackers_retrieve_response_200 import (
    OsidbApiV1TrackersRetrieveResponse200,
)
from .osidb_api_v1_trackers_update_response_200 import (
    OsidbApiV1TrackersUpdateResponse200,
)
from .osidb_healthy_retrieve_response_200 import OsidbHealthyRetrieveResponse200
from .osidb_whoami_retrieve_response_200 import OsidbWhoamiRetrieveResponse200
from .osidb_whoami_retrieve_response_200_profile import (
    OsidbWhoamiRetrieveResponse200Profile,
)
from .package import Package
from .package_request import PackageRequest
from .package_ver import PackageVer
from .package_ver_request import PackageVerRequest
from .paginated_affect_cvss_list import PaginatedAffectCVSSList
from .paginated_affect_list import PaginatedAffectList
from .paginated_alert_list import PaginatedAlertList
from .paginated_audit_list import PaginatedAuditList
from .paginated_epss_list import PaginatedEPSSList
from .paginated_exploit_only_report_data_list import PaginatedExploitOnlyReportDataList
from .paginated_flaw_acknowledgment_list import PaginatedFlawAcknowledgmentList
from .paginated_flaw_collaborator_list import PaginatedFlawCollaboratorList
from .paginated_flaw_comment_list import PaginatedFlawCommentList
from .paginated_flaw_cvss_list import PaginatedFlawCVSSList
from .paginated_flaw_label_list import PaginatedFlawLabelList
from .paginated_flaw_list import PaginatedFlawList
from .paginated_flaw_package_version_list import PaginatedFlawPackageVersionList
from .paginated_flaw_reference_list import PaginatedFlawReferenceList
from .paginated_flaw_report_data_list import PaginatedFlawReportDataList
from .paginated_supported_products_list import PaginatedSupportedProductsList
from .paginated_tracker_list import PaginatedTrackerList
from .ps_stream_selection import PsStreamSelection
from .reject_request import RejectRequest
from .requires_cve_description_enum import RequiresCveDescriptionEnum
from .resolution_enum import ResolutionEnum
from .source_be_0_enum import SourceBe0Enum
from .special_handling_enum import SpecialHandlingEnum
from .state_enum import StateEnum
from .supported_products import SupportedProducts
from .token_obtain_pair import TokenObtainPair
from .token_obtain_pair_request import TokenObtainPairRequest
from .token_refresh import TokenRefresh
from .token_refresh_request import TokenRefreshRequest
from .token_verify_request import TokenVerifyRequest
from .tracker import Tracker
from .tracker_post import TrackerPost
from .tracker_post_request import TrackerPostRequest
from .tracker_report_data import TrackerReportData
from .tracker_request import TrackerRequest
from .tracker_suggestion import TrackerSuggestion
from .tracker_type import TrackerType
from .trackers_api_v1_file_create_response_200 import TrackersApiV1FileCreateResponse200
from .workflows_api_v1_workflows_adjust_create_response_200 import (
    WorkflowsApiV1WorkflowsAdjustCreateResponse200,
)
from .workflows_api_v1_workflows_retrieve_2_response_200 import (
    WorkflowsApiV1WorkflowsRetrieve2Response200,
)
from .workflows_api_v1_workflows_retrieve_response_200 import (
    WorkflowsApiV1WorkflowsRetrieveResponse200,
)
from .workflows_healthy_retrieve_response_200 import WorkflowsHealthyRetrieveResponse200
from .workflows_retrieve_response_200 import WorkflowsRetrieveResponse200

__all__ = (
    "Affect",
    "AffectBulkPostPutResponse",
    "AffectBulkPutRequest",
    "AffectCVSS",
    "AffectCVSSPostRequest",
    "AffectCVSSPutRequest",
    "AffectCVSSRequest",
    "AffectednessEnum",
    "AffectPostRequest",
    "AffectReportData",
    "AffectRequest",
    "Alert",
    "AlertTypeEnum",
    "Audit",
    "AuditRequest",
    "AuthTokenCreateResponse200",
    "AuthTokenRefreshCreateResponse200",
    "AuthTokenRetrieveResponse200",
    "AuthTokenVerifyCreateResponse200",
    "BlankEnum",
    "CollectorsApiV1StatusRetrieveResponse200",
    "CollectorsApiV1StatusRetrieveResponse200CollectorsItem",
    "CollectorsApiV1StatusRetrieveResponse200CollectorsItemData",
    "CollectorsApiV1StatusRetrieveResponse200CollectorsItemErrorType0",
    "CollectorsApiV1StatusRetrieveResponse200CollectorsItemState",
    "CollectorsHealthyRetrieveResponse200",
    "CollectorsRetrieveResponse200",
    "Comment",
    "CommentRequest",
    "CvssVersionEnum",
    "EPSS",
    "Erratum",
    "ExploitOnlyReportData",
    "ExploitOnlyReportDataSourceEnum",
    "ExploitsApiV1CollectUpdateResponse200",
    "ExploitsApiV1CveMapRetrieveResponse200",
    "ExploitsApiV1CveMapRetrieveResponse200Cves",
    "ExploitsApiV1EpssListResponse200",
    "ExploitsApiV1FlawDataListResponse200",
    "ExploitsApiV1ReportDataListResponse200",
    "ExploitsApiV1ReportDateRetrieveResponse200",
    "ExploitsApiV1ReportDateRetrieveResponse200ActionRequiredItem",
    "ExploitsApiV1ReportDateRetrieveResponse200NoActionItem",
    "ExploitsApiV1ReportDateRetrieveResponse200NotRelevantItem",
    "ExploitsApiV1ReportExplanationsRetrieveResponse200",
    "ExploitsApiV1ReportExplanationsRetrieveResponse200ExplanationsItem",
    "ExploitsApiV1ReportPendingRetrieveResponse200",
    "ExploitsApiV1ReportPendingRetrieveResponse200PendingActionsItem",
    "ExploitsApiV1StatusRetrieveResponse200",
    "ExploitsApiV1SupportedProductsListResponse200",
    "Flaw",
    "FlawAcknowledgment",
    "FlawAcknowledgmentPostRequest",
    "FlawAcknowledgmentPutRequest",
    "FlawAcknowledgmentRequest",
    "FlawClassification",
    "FlawClassificationState",
    "FlawCollaborator",
    "FlawCollaboratorPostRequest",
    "FlawCollaboratorRequest",
    "FlawComment",
    "FlawCommentPostRequest",
    "FlawCVSS",
    "FlawCVSSPostRequest",
    "FlawCVSSPutRequest",
    "FlawCVSSRequest",
    "FlawLabel",
    "FlawPackageVersion",
    "FlawPackageVersionPostRequest",
    "FlawPackageVersionPutRequest",
    "FlawPostRequest",
    "FlawReference",
    "FlawReferencePostRequest",
    "FlawReferencePutRequest",
    "FlawReferenceRequest",
    "FlawReferenceType",
    "FlawReportData",
    "FlawRequest",
    "FlawUUIDListRequest",
    "FlawVersion",
    "FlawVersionRequest",
    "ImpactEnum",
    "IssuerEnum",
    "MajorIncidentStateEnum",
    "MaturityPreliminaryEnum",
    "ModuleComponent",
    "NistCvssValidationEnum",
    "NotAffectedJustificationEnum",
    "OsidbApiV1AffectsBulkCreateResponse200",
    "OsidbApiV1AffectsBulkDestroyResponse200",
    "OsidbApiV1AffectsBulkUpdateResponse200",
    "OsidbApiV1AffectsCreateResponse201",
    "OsidbApiV1AffectsCvssScoresCreateResponse201",
    "OsidbApiV1AffectsCvssScoresDestroyResponse200",
    "OsidbApiV1AffectsCvssScoresListIssuer",
    "OsidbApiV1AffectsCvssScoresListResponse200",
    "OsidbApiV1AffectsCvssScoresRetrieveResponse200",
    "OsidbApiV1AffectsCvssScoresUpdateResponse200",
    "OsidbApiV1AffectsDestroyResponse200",
    "OsidbApiV1AffectsListAffectedness",
    "OsidbApiV1AffectsListCvssScoresIssuer",
    "OsidbApiV1AffectsListFlawImpact",
    "OsidbApiV1AffectsListFlawSource",
    "OsidbApiV1AffectsListImpact",
    "OsidbApiV1AffectsListOrderItem",
    "OsidbApiV1AffectsListResolution",
    "OsidbApiV1AffectsListResponse200",
    "OsidbApiV1AffectsListTrackersType",
    "OsidbApiV1AffectsRetrieveResponse200",
    "OsidbApiV1AffectsUpdateResponse200",
    "OsidbApiV1AlertsListAlertType",
    "OsidbApiV1AlertsListParentModel",
    "OsidbApiV1AlertsListResponse200",
    "OsidbApiV1AlertsRetrieveResponse200",
    "OsidbApiV1AuditListResponse200",
    "OsidbApiV1AuditRetrieveResponse200",
    "OsidbApiV1AuditUpdateResponse200",
    "OsidbApiV1FlawsAcknowledgmentsCreateResponse201",
    "OsidbApiV1FlawsAcknowledgmentsDestroyResponse200",
    "OsidbApiV1FlawsAcknowledgmentsListResponse200",
    "OsidbApiV1FlawsAcknowledgmentsRetrieveResponse200",
    "OsidbApiV1FlawsAcknowledgmentsUpdateResponse200",
    "OsidbApiV1FlawsCommentsCreateResponse201",
    "OsidbApiV1FlawsCommentsListResponse200",
    "OsidbApiV1FlawsCommentsRetrieveResponse200",
    "OsidbApiV1FlawsCreateResponse201",
    "OsidbApiV1FlawsCvssScoresCreateResponse201",
    "OsidbApiV1FlawsCvssScoresDestroyResponse200",
    "OsidbApiV1FlawsCvssScoresListIssuer",
    "OsidbApiV1FlawsCvssScoresListResponse200",
    "OsidbApiV1FlawsCvssScoresRetrieveResponse200",
    "OsidbApiV1FlawsCvssScoresUpdateResponse200",
    "OsidbApiV1FlawsLabelsCreateResponse201",
    "OsidbApiV1FlawsLabelsDestroyResponse204",
    "OsidbApiV1FlawsLabelsListResponse200",
    "OsidbApiV1FlawsLabelsRetrieveResponse200",
    "OsidbApiV1FlawsLabelsUpdateResponse200",
    "OsidbApiV1FlawsListAffectsAffectedness",
    "OsidbApiV1FlawsListAffectsImpact",
    "OsidbApiV1FlawsListAffectsResolution",
    "OsidbApiV1FlawsListAffectsTrackersType",
    "OsidbApiV1FlawsListCvssScoresIssuer",
    "OsidbApiV1FlawsListImpact",
    "OsidbApiV1FlawsListMajorIncidentState",
    "OsidbApiV1FlawsListNistCvssValidation",
    "OsidbApiV1FlawsListOrderItem",
    "OsidbApiV1FlawsListReferencesType",
    "OsidbApiV1FlawsListRequiresCveDescription",
    "OsidbApiV1FlawsListResponse200",
    "OsidbApiV1FlawsListSource",
    "OsidbApiV1FlawsListWorkflowStateItem",
    "OsidbApiV1FlawsPackageVersionsCreateResponse201",
    "OsidbApiV1FlawsPackageVersionsDestroyResponse200",
    "OsidbApiV1FlawsPackageVersionsListResponse200",
    "OsidbApiV1FlawsPackageVersionsRetrieveResponse200",
    "OsidbApiV1FlawsPackageVersionsUpdateResponse200",
    "OsidbApiV1FlawsPromoteCreateResponse200",
    "OsidbApiV1FlawsReferencesCreateResponse201",
    "OsidbApiV1FlawsReferencesDestroyResponse200",
    "OsidbApiV1FlawsReferencesListResponse200",
    "OsidbApiV1FlawsReferencesListType",
    "OsidbApiV1FlawsReferencesRetrieveResponse200",
    "OsidbApiV1FlawsReferencesUpdateResponse200",
    "OsidbApiV1FlawsRejectCreateResponse200",
    "OsidbApiV1FlawsRetrieveResponse200",
    "OsidbApiV1FlawsUpdateResponse200",
    "OsidbApiV1LabelsListResponse200",
    "OsidbApiV1LabelsRetrieveResponse200",
    "OsidbApiV1ManifestRetrieveResponse200",
    "OsidbApiV1SchemaRetrieveFormat",
    "OsidbApiV1SchemaRetrieveLang",
    "OsidbApiV1SchemaRetrieveResponse200",
    "OsidbApiV1StatusRetrieveResponse200",
    "OsidbApiV1StatusRetrieveResponse200OsidbData",
    "OsidbApiV1StatusRetrieveResponse200OsidbService",
    "OsidbApiV1TrackersCreateResponse201",
    "OsidbApiV1TrackersListAffectsAffectedness",
    "OsidbApiV1TrackersListAffectsFlawImpact",
    "OsidbApiV1TrackersListAffectsFlawSource",
    "OsidbApiV1TrackersListAffectsImpact",
    "OsidbApiV1TrackersListAffectsResolution",
    "OsidbApiV1TrackersListOrderItem",
    "OsidbApiV1TrackersListResponse200",
    "OsidbApiV1TrackersListType",
    "OsidbApiV1TrackersRetrieveResponse200",
    "OsidbApiV1TrackersUpdateResponse200",
    "OsidbHealthyRetrieveResponse200",
    "OsidbWhoamiRetrieveResponse200",
    "OsidbWhoamiRetrieveResponse200Profile",
    "Package",
    "PackageRequest",
    "PackageVer",
    "PackageVerRequest",
    "PaginatedAffectCVSSList",
    "PaginatedAffectList",
    "PaginatedAlertList",
    "PaginatedAuditList",
    "PaginatedEPSSList",
    "PaginatedExploitOnlyReportDataList",
    "PaginatedFlawAcknowledgmentList",
    "PaginatedFlawCollaboratorList",
    "PaginatedFlawCommentList",
    "PaginatedFlawCVSSList",
    "PaginatedFlawLabelList",
    "PaginatedFlawList",
    "PaginatedFlawPackageVersionList",
    "PaginatedFlawReferenceList",
    "PaginatedFlawReportDataList",
    "PaginatedSupportedProductsList",
    "PaginatedTrackerList",
    "PsStreamSelection",
    "RejectRequest",
    "RequiresCveDescriptionEnum",
    "ResolutionEnum",
    "SourceBe0Enum",
    "SpecialHandlingEnum",
    "StateEnum",
    "SupportedProducts",
    "TokenObtainPair",
    "TokenObtainPairRequest",
    "TokenRefresh",
    "TokenRefreshRequest",
    "TokenVerifyRequest",
    "Tracker",
    "TrackerPost",
    "TrackerPostRequest",
    "TrackerReportData",
    "TrackerRequest",
    "TrackersApiV1FileCreateResponse200",
    "TrackerSuggestion",
    "TrackerType",
    "WorkflowsApiV1WorkflowsAdjustCreateResponse200",
    "WorkflowsApiV1WorkflowsRetrieve2Response200",
    "WorkflowsApiV1WorkflowsRetrieveResponse200",
    "WorkflowsHealthyRetrieveResponse200",
    "WorkflowsRetrieveResponse200",
)



from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.osidb_api_v1_flaws_references_destroy_response_200 import (
    OsidbApiV1FlawsReferencesDestroyResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {}


def _get_kwargs(
    flaw_id: UUID,
    id: str,
    *,
    client: AuthenticatedClient,
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/flaws/{flaw_id}/references/{id}".format(
            flaw_id=flaw_id,
            id=id,
        ),
    }

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1FlawsReferencesDestroyResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1FlawsReferencesDestroyResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1FlawsReferencesDestroyResponse200.from_dict(
                _response_200
            )

        return response_200


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1FlawsReferencesDestroyResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    flaw_id: UUID,
    id: str,
    *,
    client: AuthenticatedClient,
) -> Response[OsidbApiV1FlawsReferencesDestroyResponse200]:
    """Destroy the instance and proxy the delete to Bugzilla

    Args:
        flaw_id (UUID):
        id (str):
        bugzilla_api_key (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsReferencesDestroyResponse200]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        id=id,
        client=client,
    )

    response = requests.delete(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    flaw_id: UUID,
    id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[OsidbApiV1FlawsReferencesDestroyResponse200]:
    """Destroy the instance and proxy the delete to Bugzilla

    Args:
        flaw_id (UUID):
        id (str):
        bugzilla_api_key (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsReferencesDestroyResponse200
    """

    return sync_detailed(
        flaw_id=flaw_id,
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    flaw_id: UUID,
    id: str,
    *,
    client: AuthenticatedClient,
) -> Response[OsidbApiV1FlawsReferencesDestroyResponse200]:
    """Destroy the instance and proxy the delete to Bugzilla

    Args:
        flaw_id (UUID):
        id (str):
        bugzilla_api_key (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1FlawsReferencesDestroyResponse200]
    """

    kwargs = _get_kwargs(
        flaw_id=flaw_id,
        id=id,
        client=client,
    )

    async with client.get_async_session().delete(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    flaw_id: UUID,
    id: str,
    *,
    client: AuthenticatedClient,
) -> Optional[OsidbApiV1FlawsReferencesDestroyResponse200]:
    """Destroy the instance and proxy the delete to Bugzilla

    Args:
        flaw_id (UUID):
        id (str):
        bugzilla_api_key (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1FlawsReferencesDestroyResponse200
    """

    return (
        await asyncio_detailed(
            flaw_id=flaw_id,
            id=id,
            client=client,
        )
    ).parsed



"""
osidb-registry-bindings helpers
"""

import json
from os import getenv
from typing import Any, Union

from .exceptions import OSIDBBindingsException

_MAP = {
    "y": True,
    "yes": True,
    "t": True,
    "true": True,
    "on": True,
    "1": True,
    "n": False,
    "no": False,
    "f": False,
    "false": False,
    "off": False,
    "0": False,
}


def strtobool(value):
    try:
        return _MAP[str(value).lower()]
    except KeyError:
        raise ValueError('"{}" is not a valid bool value'.format(value))


def get_env(
    key: str,
    default: Union[None, str] = None,
    is_bool: bool = False,
    is_int: bool = False,
    is_json: bool = False,
) -> Any:
    """get environment variable"""
    if (is_bool and is_int) or (is_bool and is_json) or (is_int and is_json):
        raise OSIDBBindingsException(
            "Expected environment variable cannot be of multiple types at the same time"
        )

    value = getenv(key, default)
    # consider empty string as empty value
    # as setting the value to non-existing env variable
    # in compose.yml results in an empty string
    if value == "":
        value = default

    if is_bool:
        value = bool(strtobool(value))
    if is_int:
        value = int(value)
    if is_json:
        value = json.loads(value)

    return value



from enum import Enum


class OsidbApiV1FlawsListMajorIncidentState(str, Enum):
    APPROVED = "APPROVED"
    CISA_APPROVED = "CISA_APPROVED"
    INVALID = "INVALID"
    MINOR = "MINOR"
    REJECTED = "REJECTED"
    REQUESTED = "REQUESTED"
    VALUE_0 = ""
    ZERO_DAY = "ZERO_DAY"

    def __str__(self) -> str:
        return str(self.value)



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.blank_enum import BlankEnum
from ..models.impact_enum import ImpactEnum
from ..models.major_incident_state_enum import MajorIncidentStateEnum
from ..models.nist_cvss_validation_enum import NistCvssValidationEnum
from ..models.requires_cve_description_enum import RequiresCveDescriptionEnum
from ..models.source_be_0_enum import SourceBe0Enum
from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.affect import Affect
    from ..models.alert import Alert
    from ..models.comment import Comment
    from ..models.flaw_acknowledgment import FlawAcknowledgment
    from ..models.flaw_classification import FlawClassification
    from ..models.flaw_collaborator import FlawCollaborator
    from ..models.flaw_cvss import FlawCVSS
    from ..models.flaw_reference import FlawReference
    from ..models.package import Package


T = TypeVar("T", bound="OsidbApiV1FlawsUpdateResponse200")


@_attrs_define
class OsidbApiV1FlawsUpdateResponse200(OSIDBModel):
    """
    Attributes:
        uuid (UUID):
        title (str):
        trackers (list[str]):
        comment_zero (str):
        affects (list['Affect']):
        comments (list['Comment']):
        package_versions (list['Package']):
        acknowledgments (list['FlawAcknowledgment']):
        references (list['FlawReference']):
        cvss_scores (list['FlawCVSS']):
        labels (list['FlawCollaborator']):
        embargoed (bool): The embargoed boolean attribute is technically read-only as it just indirectly modifies the
            ACLs but is mandatory as it controls the access to the resource.
        created_dt (datetime.datetime):
        updated_dt (datetime.datetime): The updated_dt timestamp attribute is mandatory on update as it is used to
            detect mit-air collisions.
        classification (FlawClassification):
        task_key (Union[None, str]):
        alerts (list['Alert']):
        cve_id (Union[None, Unset, str]):
        impact (Union[BlankEnum, ImpactEnum, Unset]):
        components (Union[Unset, list[str]]):
        cve_description (Union[Unset, str]):
        requires_cve_description (Union[BlankEnum, RequiresCveDescriptionEnum, Unset]):
        statement (Union[Unset, str]):
        cwe_id (Union[Unset, str]):
        unembargo_dt (Union[None, Unset, datetime.datetime]):
        source (Union[BlankEnum, SourceBe0Enum, Unset]):
        reported_dt (Union[None, Unset, datetime.datetime]):
        mitigation (Union[Unset, str]):
        major_incident_state (Union[BlankEnum, MajorIncidentStateEnum, Unset]):
        major_incident_start_dt (Union[None, Unset, datetime.datetime]):
        nist_cvss_validation (Union[BlankEnum, NistCvssValidationEnum, Unset]):
        group_key (Union[Unset, str]):
        owner (Union[Unset, str]):
        team_id (Union[Unset, str]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    uuid: UUID
    title: str
    trackers: list[str]
    comment_zero: str
    affects: list["Affect"]
    comments: list["Comment"]
    package_versions: list["Package"]
    acknowledgments: list["FlawAcknowledgment"]
    references: list["FlawReference"]
    cvss_scores: list["FlawCVSS"]
    labels: list["FlawCollaborator"]
    embargoed: bool
    created_dt: datetime.datetime
    updated_dt: datetime.datetime
    classification: "FlawClassification"
    task_key: Union[None, str]
    alerts: list["Alert"]
    cve_id: Union[None, Unset, str] = UNSET
    impact: Union[BlankEnum, ImpactEnum, Unset] = UNSET
    components: Union[Unset, list[str]] = UNSET
    cve_description: Union[Unset, str] = UNSET
    requires_cve_description: Union[BlankEnum, RequiresCveDescriptionEnum, Unset] = (
        UNSET
    )
    statement: Union[Unset, str] = UNSET
    cwe_id: Union[Unset, str] = UNSET
    unembargo_dt: Union[None, Unset, datetime.datetime] = UNSET
    source: Union[BlankEnum, SourceBe0Enum, Unset] = UNSET
    reported_dt: Union[None, Unset, datetime.datetime] = UNSET
    mitigation: Union[Unset, str] = UNSET
    major_incident_state: Union[BlankEnum, MajorIncidentStateEnum, Unset] = UNSET
    major_incident_start_dt: Union[None, Unset, datetime.datetime] = UNSET
    nist_cvss_validation: Union[BlankEnum, NistCvssValidationEnum, Unset] = UNSET
    group_key: Union[Unset, str] = UNSET
    owner: Union[Unset, str] = UNSET
    team_id: Union[Unset, str] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        uuid: str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        title = self.title

        trackers: list[str] = UNSET
        if not isinstance(self.trackers, Unset):
            trackers = self.trackers

        comment_zero = self.comment_zero

        affects: list[dict[str, Any]] = UNSET
        if not isinstance(self.affects, Unset):
            affects = []
            for affects_item_data in self.affects:
                affects_item: dict[str, Any] = UNSET
                if not isinstance(affects_item_data, Unset):
                    affects_item = affects_item_data.to_dict()

                affects.append(affects_item)

        comments: list[dict[str, Any]] = UNSET
        if not isinstance(self.comments, Unset):
            comments = []
            for comments_item_data in self.comments:
                comments_item: dict[str, Any] = UNSET
                if not isinstance(comments_item_data, Unset):
                    comments_item = comments_item_data.to_dict()

                comments.append(comments_item)

        package_versions: list[dict[str, Any]] = UNSET
        if not isinstance(self.package_versions, Unset):
            package_versions = []
            for package_versions_item_data in self.package_versions:
                package_versions_item: dict[str, Any] = UNSET
                if not isinstance(package_versions_item_data, Unset):
                    package_versions_item = package_versions_item_data.to_dict()

                package_versions.append(package_versions_item)

        acknowledgments: list[dict[str, Any]] = UNSET
        if not isinstance(self.acknowledgments, Unset):
            acknowledgments = []
            for acknowledgments_item_data in self.acknowledgments:
                acknowledgments_item: dict[str, Any] = UNSET
                if not isinstance(acknowledgments_item_data, Unset):
                    acknowledgments_item = acknowledgments_item_data.to_dict()

                acknowledgments.append(acknowledgments_item)

        references: list[dict[str, Any]] = UNSET
        if not isinstance(self.references, Unset):
            references = []
            for references_item_data in self.references:
                references_item: dict[str, Any] = UNSET
                if not isinstance(references_item_data, Unset):
                    references_item = references_item_data.to_dict()

                references.append(references_item)

        cvss_scores: list[dict[str, Any]] = UNSET
        if not isinstance(self.cvss_scores, Unset):
            cvss_scores = []
            for cvss_scores_item_data in self.cvss_scores:
                cvss_scores_item: dict[str, Any] = UNSET
                if not isinstance(cvss_scores_item_data, Unset):
                    cvss_scores_item = cvss_scores_item_data.to_dict()

                cvss_scores.append(cvss_scores_item)

        labels: list[dict[str, Any]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = []
            for labels_item_data in self.labels:
                labels_item: dict[str, Any] = UNSET
                if not isinstance(labels_item_data, Unset):
                    labels_item = labels_item_data.to_dict()

                labels.append(labels_item)

        embargoed = self.embargoed

        created_dt: str = UNSET
        if not isinstance(self.created_dt, Unset):
            created_dt = self.created_dt.isoformat()

        updated_dt: str = UNSET
        if not isinstance(self.updated_dt, Unset):
            updated_dt = self.updated_dt.isoformat()

        classification: dict[str, Any] = UNSET
        if not isinstance(self.classification, Unset):
            classification = self.classification.to_dict()

        task_key: Union[None, str]
        if isinstance(self.task_key, Unset):
            task_key = UNSET
        task_key = self.task_key

        alerts: list[dict[str, Any]] = UNSET
        if not isinstance(self.alerts, Unset):
            alerts = []
            for alerts_item_data in self.alerts:
                alerts_item: dict[str, Any] = UNSET
                if not isinstance(alerts_item_data, Unset):
                    alerts_item = alerts_item_data.to_dict()

                alerts.append(alerts_item)

        cve_id: Union[None, Unset, str]
        if isinstance(self.cve_id, Unset):
            cve_id = UNSET
        else:
            cve_id = self.cve_id

        impact: Union[Unset, str]
        if isinstance(self.impact, Unset):
            impact = UNSET
        elif isinstance(self.impact, ImpactEnum):
            impact = UNSET
            if not isinstance(self.impact, Unset):
                impact = ImpactEnum(self.impact).value

        else:
            impact = UNSET
            if not isinstance(self.impact, Unset):
                impact = BlankEnum(self.impact).value

        components: Union[Unset, list[str]] = UNSET
        if not isinstance(self.components, Unset):
            components = self.components

        cve_description = self.cve_description

        requires_cve_description: Union[Unset, str]
        if isinstance(self.requires_cve_description, Unset):
            requires_cve_description = UNSET
        elif isinstance(self.requires_cve_description, RequiresCveDescriptionEnum):
            requires_cve_description = UNSET
            if not isinstance(self.requires_cve_description, Unset):
                requires_cve_description = RequiresCveDescriptionEnum(
                    self.requires_cve_description
                ).value

        else:
            requires_cve_description = UNSET
            if not isinstance(self.requires_cve_description, Unset):
                requires_cve_description = BlankEnum(
                    self.requires_cve_description
                ).value

        statement = self.statement

        cwe_id = self.cwe_id

        unembargo_dt: Union[None, Unset, str]
        if isinstance(self.unembargo_dt, Unset):
            unembargo_dt = UNSET
        elif isinstance(self.unembargo_dt, datetime.datetime):
            unembargo_dt = UNSET
            if not isinstance(self.unembargo_dt, Unset):
                unembargo_dt = self.unembargo_dt.isoformat()

        else:
            unembargo_dt = self.unembargo_dt

        source: Union[Unset, str]
        if isinstance(self.source, Unset):
            source = UNSET
        elif isinstance(self.source, SourceBe0Enum):
            source = UNSET
            if not isinstance(self.source, Unset):
                source = SourceBe0Enum(self.source).value

        else:
            source = UNSET
            if not isinstance(self.source, Unset):
                source = BlankEnum(self.source).value

        reported_dt: Union[None, Unset, str]
        if isinstance(self.reported_dt, Unset):
            reported_dt = UNSET
        elif isinstance(self.reported_dt, datetime.datetime):
            reported_dt = UNSET
            if not isinstance(self.reported_dt, Unset):
                reported_dt = self.reported_dt.isoformat()

        else:
            reported_dt = self.reported_dt

        mitigation = self.mitigation

        major_incident_state: Union[Unset, str]
        if isinstance(self.major_incident_state, Unset):
            major_incident_state = UNSET
        elif isinstance(self.major_incident_state, MajorIncidentStateEnum):
            major_incident_state = UNSET
            if not isinstance(self.major_incident_state, Unset):
                major_incident_state = MajorIncidentStateEnum(
                    self.major_incident_state
                ).value

        else:
            major_incident_state = UNSET
            if not isinstance(self.major_incident_state, Unset):
                major_incident_state = BlankEnum(self.major_incident_state).value

        major_incident_start_dt: Union[None, Unset, str]
        if isinstance(self.major_incident_start_dt, Unset):
            major_incident_start_dt = UNSET
        elif isinstance(self.major_incident_start_dt, datetime.datetime):
            major_incident_start_dt = UNSET
            if not isinstance(self.major_incident_start_dt, Unset):
                major_incident_start_dt = self.major_incident_start_dt.isoformat()

        else:
            major_incident_start_dt = self.major_incident_start_dt

        nist_cvss_validation: Union[Unset, str]
        if isinstance(self.nist_cvss_validation, Unset):
            nist_cvss_validation = UNSET
        elif isinstance(self.nist_cvss_validation, NistCvssValidationEnum):
            nist_cvss_validation = UNSET
            if not isinstance(self.nist_cvss_validation, Unset):
                nist_cvss_validation = NistCvssValidationEnum(
                    self.nist_cvss_validation
                ).value

        else:
            nist_cvss_validation = UNSET
            if not isinstance(self.nist_cvss_validation, Unset):
                nist_cvss_validation = BlankEnum(self.nist_cvss_validation).value

        group_key = self.group_key

        owner = self.owner

        team_id = self.team_id

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(uuid, Unset):
            field_dict["uuid"] = uuid
        if not isinstance(title, Unset):
            field_dict["title"] = title
        if not isinstance(trackers, Unset):
            field_dict["trackers"] = trackers
        if not isinstance(comment_zero, Unset):
            field_dict["comment_zero"] = comment_zero
        if not isinstance(affects, Unset):
            field_dict["affects"] = affects
        if not isinstance(comments, Unset):
            field_dict["comments"] = comments
        if not isinstance(package_versions, Unset):
            field_dict["package_versions"] = package_versions
        if not isinstance(acknowledgments, Unset):
            field_dict["acknowledgments"] = acknowledgments
        if not isinstance(references, Unset):
            field_dict["references"] = references
        if not isinstance(cvss_scores, Unset):
            field_dict["cvss_scores"] = cvss_scores
        if not isinstance(labels, Unset):
            field_dict["labels"] = labels
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(created_dt, Unset):
            field_dict["created_dt"] = created_dt
        if not isinstance(updated_dt, Unset):
            field_dict["updated_dt"] = updated_dt
        if not isinstance(classification, Unset):
            field_dict["classification"] = classification
        if not isinstance(task_key, Unset):
            field_dict["task_key"] = task_key
        if not isinstance(alerts, Unset):
            field_dict["alerts"] = alerts
        if not isinstance(cve_id, Unset):
            field_dict["cve_id"] = cve_id
        if not isinstance(impact, Unset):
            field_dict["impact"] = impact
        if not isinstance(components, Unset):
            field_dict["components"] = components
        if not isinstance(cve_description, Unset):
            field_dict["cve_description"] = cve_description
        if not isinstance(requires_cve_description, Unset):
            field_dict["requires_cve_description"] = requires_cve_description
        if not isinstance(statement, Unset):
            field_dict["statement"] = statement
        if not isinstance(cwe_id, Unset):
            field_dict["cwe_id"] = cwe_id
        if not isinstance(unembargo_dt, Unset):
            field_dict["unembargo_dt"] = unembargo_dt
        if not isinstance(source, Unset):
            field_dict["source"] = source
        if not isinstance(reported_dt, Unset):
            field_dict["reported_dt"] = reported_dt
        if not isinstance(mitigation, Unset):
            field_dict["mitigation"] = mitigation
        if not isinstance(major_incident_state, Unset):
            field_dict["major_incident_state"] = major_incident_state
        if not isinstance(major_incident_start_dt, Unset):
            field_dict["major_incident_start_dt"] = major_incident_start_dt
        if not isinstance(nist_cvss_validation, Unset):
            field_dict["nist_cvss_validation"] = nist_cvss_validation
        if not isinstance(group_key, Unset):
            field_dict["group_key"] = group_key
        if not isinstance(owner, Unset):
            field_dict["owner"] = owner
        if not isinstance(team_id, Unset):
            field_dict["team_id"] = team_id
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.affect import Affect
        from ..models.alert import Alert
        from ..models.comment import Comment
        from ..models.flaw_acknowledgment import FlawAcknowledgment
        from ..models.flaw_classification import FlawClassification
        from ..models.flaw_collaborator import FlawCollaborator
        from ..models.flaw_cvss import FlawCVSS
        from ..models.flaw_reference import FlawReference
        from ..models.package import Package

        d = src_dict.copy()
        _uuid = d.pop("uuid", UNSET)
        uuid: UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = _uuid if isinstance(_uuid, UUID) else UUID(_uuid)

        title = d.pop("title", UNSET)

        trackers = cast(list[str], d.pop("trackers", UNSET))

        comment_zero = d.pop("comment_zero", UNSET)

        affects = []
        _affects = d.pop("affects", UNSET)
        for affects_item_data in _affects or []:
            _affects_item = affects_item_data
            affects_item: Affect
            if isinstance(_affects_item, Unset):
                affects_item = UNSET
            else:
                affects_item = Affect.from_dict(_affects_item)

            affects.append(affects_item)

        comments = []
        _comments = d.pop("comments", UNSET)
        for comments_item_data in _comments or []:
            _comments_item = comments_item_data
            comments_item: Comment
            if isinstance(_comments_item, Unset):
                comments_item = UNSET
            else:
                comments_item = Comment.from_dict(_comments_item)

            comments.append(comments_item)

        package_versions = []
        _package_versions = d.pop("package_versions", UNSET)
        for package_versions_item_data in _package_versions or []:
            _package_versions_item = package_versions_item_data
            package_versions_item: Package
            if isinstance(_package_versions_item, Unset):
                package_versions_item = UNSET
            else:
                package_versions_item = Package.from_dict(_package_versions_item)

            package_versions.append(package_versions_item)

        acknowledgments = []
        _acknowledgments = d.pop("acknowledgments", UNSET)
        for acknowledgments_item_data in _acknowledgments or []:
            _acknowledgments_item = acknowledgments_item_data
            acknowledgments_item: FlawAcknowledgment
            if isinstance(_acknowledgments_item, Unset):
                acknowledgments_item = UNSET
            else:
                acknowledgments_item = FlawAcknowledgment.from_dict(
                    _acknowledgments_item
                )

            acknowledgments.append(acknowledgments_item)

        references = []
        _references = d.pop("references", UNSET)
        for references_item_data in _references or []:
            _references_item = references_item_data
            references_item: FlawReference
            if isinstance(_references_item, Unset):
                references_item = UNSET
            else:
                references_item = FlawReference.from_dict(_references_item)

            references.append(references_item)

        cvss_scores = []
        _cvss_scores = d.pop("cvss_scores", UNSET)
        for cvss_scores_item_data in _cvss_scores or []:
            _cvss_scores_item = cvss_scores_item_data
            cvss_scores_item: FlawCVSS
            if isinstance(_cvss_scores_item, Unset):
                cvss_scores_item = UNSET
            else:
                cvss_scores_item = FlawCVSS.from_dict(_cvss_scores_item)

            cvss_scores.append(cvss_scores_item)

        labels = []
        _labels = d.pop("labels", UNSET)
        for labels_item_data in _labels or []:
            _labels_item = labels_item_data
            labels_item: FlawCollaborator
            if isinstance(_labels_item, Unset):
                labels_item = UNSET
            else:
                labels_item = FlawCollaborator.from_dict(_labels_item)

            labels.append(labels_item)

        embargoed = d.pop("embargoed", UNSET)

        _created_dt = d.pop("created_dt", UNSET)
        created_dt: datetime.datetime
        if isinstance(_created_dt, Unset):
            created_dt = UNSET
        else:
            created_dt = isoparse(_created_dt)

        _updated_dt = d.pop("updated_dt", UNSET)
        updated_dt: datetime.datetime
        if isinstance(_updated_dt, Unset):
            updated_dt = UNSET
        else:
            updated_dt = isoparse(_updated_dt)

        _classification = d.pop("classification", UNSET)
        classification: FlawClassification
        if isinstance(_classification, Unset):
            classification = UNSET
        else:
            classification = FlawClassification.from_dict(_classification)

        def _parse_task_key(data: object) -> Union[None, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, str], data)

        task_key = _parse_task_key(d.pop("task_key", UNSET))

        alerts = []
        _alerts = d.pop("alerts", UNSET)
        for alerts_item_data in _alerts or []:
            _alerts_item = alerts_item_data
            alerts_item: Alert
            if isinstance(_alerts_item, Unset):
                alerts_item = UNSET
            else:
                alerts_item = Alert.from_dict(_alerts_item)

            alerts.append(alerts_item)

        def _parse_cve_id(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        cve_id = _parse_cve_id(d.pop("cve_id", UNSET))

        def _parse_impact(data: object) -> Union[BlankEnum, ImpactEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _impact_type_0 = data
                impact_type_0: ImpactEnum
                if isinstance(_impact_type_0, Unset):
                    impact_type_0 = UNSET
                else:
                    impact_type_0 = ImpactEnum(_impact_type_0)

                return impact_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _impact_type_1 = data
            impact_type_1: BlankEnum
            if isinstance(_impact_type_1, Unset):
                impact_type_1 = UNSET
            else:
                impact_type_1 = BlankEnum(_impact_type_1)

            return impact_type_1

        impact = _parse_impact(d.pop("impact", UNSET))

        components = cast(list[str], d.pop("components", UNSET))

        cve_description = d.pop("cve_description", UNSET)

        def _parse_requires_cve_description(
            data: object,
        ) -> Union[BlankEnum, RequiresCveDescriptionEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _requires_cve_description_type_0 = data
                requires_cve_description_type_0: RequiresCveDescriptionEnum
                if isinstance(_requires_cve_description_type_0, Unset):
                    requires_cve_description_type_0 = UNSET
                else:
                    requires_cve_description_type_0 = RequiresCveDescriptionEnum(
                        _requires_cve_description_type_0
                    )

                return requires_cve_description_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _requires_cve_description_type_1 = data
            requires_cve_description_type_1: BlankEnum
            if isinstance(_requires_cve_description_type_1, Unset):
                requires_cve_description_type_1 = UNSET
            else:
                requires_cve_description_type_1 = BlankEnum(
                    _requires_cve_description_type_1
                )

            return requires_cve_description_type_1

        requires_cve_description = _parse_requires_cve_description(
            d.pop("requires_cve_description", UNSET)
        )

        statement = d.pop("statement", UNSET)

        cwe_id = d.pop("cwe_id", UNSET)

        def _parse_unembargo_dt(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _unembargo_dt_type_0 = data
                unembargo_dt_type_0: datetime.datetime
                if isinstance(_unembargo_dt_type_0, Unset):
                    unembargo_dt_type_0 = UNSET
                else:
                    unembargo_dt_type_0 = isoparse(_unembargo_dt_type_0)

                return unembargo_dt_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        unembargo_dt = _parse_unembargo_dt(d.pop("unembargo_dt", UNSET))

        def _parse_source(data: object) -> Union[BlankEnum, SourceBe0Enum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _source_type_0 = data
                source_type_0: SourceBe0Enum
                if isinstance(_source_type_0, Unset):
                    source_type_0 = UNSET
                else:
                    source_type_0 = SourceBe0Enum(_source_type_0)

                return source_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _source_type_1 = data
            source_type_1: BlankEnum
            if isinstance(_source_type_1, Unset):
                source_type_1 = UNSET
            else:
                source_type_1 = BlankEnum(_source_type_1)

            return source_type_1

        source = _parse_source(d.pop("source", UNSET))

        def _parse_reported_dt(data: object) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _reported_dt_type_0 = data
                reported_dt_type_0: datetime.datetime
                if isinstance(_reported_dt_type_0, Unset):
                    reported_dt_type_0 = UNSET
                else:
                    reported_dt_type_0 = isoparse(_reported_dt_type_0)

                return reported_dt_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        reported_dt = _parse_reported_dt(d.pop("reported_dt", UNSET))

        mitigation = d.pop("mitigation", UNSET)

        def _parse_major_incident_state(
            data: object,
        ) -> Union[BlankEnum, MajorIncidentStateEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _major_incident_state_type_0 = data
                major_incident_state_type_0: MajorIncidentStateEnum
                if isinstance(_major_incident_state_type_0, Unset):
                    major_incident_state_type_0 = UNSET
                else:
                    major_incident_state_type_0 = MajorIncidentStateEnum(
                        _major_incident_state_type_0
                    )

                return major_incident_state_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _major_incident_state_type_1 = data
            major_incident_state_type_1: BlankEnum
            if isinstance(_major_incident_state_type_1, Unset):
                major_incident_state_type_1 = UNSET
            else:
                major_incident_state_type_1 = BlankEnum(_major_incident_state_type_1)

            return major_incident_state_type_1

        major_incident_state = _parse_major_incident_state(
            d.pop("major_incident_state", UNSET)
        )

        def _parse_major_incident_start_dt(
            data: object,
        ) -> Union[None, Unset, datetime.datetime]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _major_incident_start_dt_type_0 = data
                major_incident_start_dt_type_0: datetime.datetime
                if isinstance(_major_incident_start_dt_type_0, Unset):
                    major_incident_start_dt_type_0 = UNSET
                else:
                    major_incident_start_dt_type_0 = isoparse(
                        _major_incident_start_dt_type_0
                    )

                return major_incident_start_dt_type_0
            except:  # noqa: E722
                pass
            return cast(Union[None, Unset, datetime.datetime], data)

        major_incident_start_dt = _parse_major_incident_start_dt(
            d.pop("major_incident_start_dt", UNSET)
        )

        def _parse_nist_cvss_validation(
            data: object,
        ) -> Union[BlankEnum, NistCvssValidationEnum, Unset]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                _nist_cvss_validation_type_0 = data
                nist_cvss_validation_type_0: NistCvssValidationEnum
                if isinstance(_nist_cvss_validation_type_0, Unset):
                    nist_cvss_validation_type_0 = UNSET
                else:
                    nist_cvss_validation_type_0 = NistCvssValidationEnum(
                        _nist_cvss_validation_type_0
                    )

                return nist_cvss_validation_type_0
            except:  # noqa: E722
                pass
            if not isinstance(data, str):
                raise TypeError()
            _nist_cvss_validation_type_1 = data
            nist_cvss_validation_type_1: BlankEnum
            if isinstance(_nist_cvss_validation_type_1, Unset):
                nist_cvss_validation_type_1 = UNSET
            else:
                nist_cvss_validation_type_1 = BlankEnum(_nist_cvss_validation_type_1)

            return nist_cvss_validation_type_1

        nist_cvss_validation = _parse_nist_cvss_validation(
            d.pop("nist_cvss_validation", UNSET)
        )

        group_key = d.pop("group_key", UNSET)

        owner = d.pop("owner", UNSET)

        team_id = d.pop("team_id", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_flaws_update_response_200 = cls(
            uuid=uuid,
            title=title,
            trackers=trackers,
            comment_zero=comment_zero,
            affects=affects,
            comments=comments,
            package_versions=package_versions,
            acknowledgments=acknowledgments,
            references=references,
            cvss_scores=cvss_scores,
            labels=labels,
            embargoed=embargoed,
            created_dt=created_dt,
            updated_dt=updated_dt,
            classification=classification,
            task_key=task_key,
            alerts=alerts,
            cve_id=cve_id,
            impact=impact,
            components=components,
            cve_description=cve_description,
            requires_cve_description=requires_cve_description,
            statement=statement,
            cwe_id=cwe_id,
            unembargo_dt=unembargo_dt,
            source=source,
            reported_dt=reported_dt,
            mitigation=mitigation,
            major_incident_state=major_incident_state,
            major_incident_start_dt=major_incident_start_dt,
            nist_cvss_validation=nist_cvss_validation,
            group_key=group_key,
            owner=owner,
            team_id=team_id,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v1_flaws_update_response_200.additional_properties = d
        return osidb_api_v1_flaws_update_response_200

    @staticmethod
    def get_fields():
        return {
            "uuid": UUID,
            "title": str,
            "trackers": list[str],
            "comment_zero": str,
            "affects": list["Affect"],
            "comments": list["Comment"],
            "package_versions": list["Package"],
            "acknowledgments": list["FlawAcknowledgment"],
            "references": list["FlawReference"],
            "cvss_scores": list["FlawCVSS"],
            "labels": list["FlawCollaborator"],
            "embargoed": bool,
            "created_dt": datetime.datetime,
            "updated_dt": datetime.datetime,
            "classification": FlawClassification,
            "task_key": Union[None, str],
            "alerts": list["Alert"],
            "cve_id": Union[None, str],
            "impact": Union[BlankEnum, ImpactEnum],
            "components": list[str],
            "cve_description": str,
            "requires_cve_description": Union[BlankEnum, RequiresCveDescriptionEnum],
            "statement": str,
            "cwe_id": str,
            "unembargo_dt": Union[None, datetime.datetime],
            "source": Union[BlankEnum, SourceBe0Enum],
            "reported_dt": Union[None, datetime.datetime],
            "mitigation": str,
            "major_incident_state": Union[BlankEnum, MajorIncidentStateEnum],
            "major_incident_start_dt": Union[None, datetime.datetime],
            "nist_cvss_validation": Union[BlankEnum, NistCvssValidationEnum],
            "group_key": str,
            "owner": str,
            "team_id": str,
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.osidb_whoami_retrieve_response_200_profile import (
        OsidbWhoamiRetrieveResponse200Profile,
    )


T = TypeVar("T", bound="OsidbWhoamiRetrieveResponse200")


@_attrs_define
class OsidbWhoamiRetrieveResponse200(OSIDBModel):
    """
    Attributes:
        dt (Union[Unset, datetime.datetime]):
        email (Union[Unset, str]):
        env (Union[Unset, str]):
        groups (Union[Unset, list[str]]):
        profile (Union[Unset, OsidbWhoamiRetrieveResponse200Profile]):
        revision (Union[Unset, str]):
        username (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    dt: Union[Unset, datetime.datetime] = UNSET
    email: Union[Unset, str] = UNSET
    env: Union[Unset, str] = UNSET
    groups: Union[Unset, list[str]] = UNSET
    profile: Union[Unset, "OsidbWhoamiRetrieveResponse200Profile"] = UNSET
    revision: Union[Unset, str] = UNSET
    username: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        email = self.email

        env = self.env

        groups: Union[Unset, list[str]] = UNSET
        if not isinstance(self.groups, Unset):
            groups = self.groups

        profile: Union[Unset, dict[str, Any]] = UNSET
        if not isinstance(self.profile, Unset):
            profile = self.profile.to_dict()

        revision = self.revision

        username = self.username

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(email, Unset):
            field_dict["email"] = email
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(groups, Unset):
            field_dict["groups"] = groups
        if not isinstance(profile, Unset):
            field_dict["profile"] = profile
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(username, Unset):
            field_dict["username"] = username
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.osidb_whoami_retrieve_response_200_profile import (
            OsidbWhoamiRetrieveResponse200Profile,
        )

        d = src_dict.copy()
        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        email = d.pop("email", UNSET)

        env = d.pop("env", UNSET)

        groups = cast(list[str], d.pop("groups", UNSET))

        _profile = d.pop("profile", UNSET)
        profile: Union[Unset, OsidbWhoamiRetrieveResponse200Profile]
        if isinstance(_profile, Unset):
            profile = UNSET
        else:
            profile = OsidbWhoamiRetrieveResponse200Profile.from_dict(_profile)

        revision = d.pop("revision", UNSET)

        username = d.pop("username", UNSET)

        version = d.pop("version", UNSET)

        osidb_whoami_retrieve_response_200 = cls(
            dt=dt,
            email=email,
            env=env,
            groups=groups,
            profile=profile,
            revision=revision,
            username=username,
            version=version,
        )

        osidb_whoami_retrieve_response_200.additional_properties = d
        return osidb_whoami_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "dt": datetime.datetime,
            "email": str,
            "env": str,
            "groups": list[str],
            "profile": OsidbWhoamiRetrieveResponse200Profile,
            "revision": str,
            "username": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="FlawCommentPostRequest")


@_attrs_define
class FlawCommentPostRequest(OSIDBModel):
    """FlawComment serializer for use by flaw_comments endpoint

    Attributes:
        text (str):
        embargoed (bool): The embargoed boolean attribute is technically read-only as it just indirectly modifies the
            ACLs but is mandatory as it controls the access to the resource.
        creator (Union[Unset, str]):
        is_private (Union[Unset, bool]):
    """

    text: str
    embargoed: bool
    creator: Union[Unset, str] = UNSET
    is_private: Union[Unset, bool] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        text = self.text

        embargoed = self.embargoed

        creator = self.creator

        is_private = self.is_private

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(text, Unset):
            field_dict["text"] = text
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(creator, Unset):
            field_dict["creator"] = creator
        if not isinstance(is_private, Unset):
            field_dict["is_private"] = is_private

        return field_dict

    def to_multipart(self) -> dict[str, Any]:
        text = (None, str(self.text).encode(), "text/plain")

        embargoed = (None, str(self.embargoed).encode(), "text/plain")

        creator = (
            self.creator
            if isinstance(self.creator, Unset)
            else (None, str(self.creator).encode(), "text/plain")
        )

        is_private = (
            self.is_private
            if isinstance(self.is_private, Unset)
            else (None, str(self.is_private).encode(), "text/plain")
        )

        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = (None, str(prop).encode(), "text/plain")

        if not isinstance(text, Unset):
            field_dict["text"] = text
        if not isinstance(embargoed, Unset):
            field_dict["embargoed"] = embargoed
        if not isinstance(creator, Unset):
            field_dict["creator"] = creator
        if not isinstance(is_private, Unset):
            field_dict["is_private"] = is_private

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        text = d.pop("text", UNSET)

        embargoed = d.pop("embargoed", UNSET)

        creator = d.pop("creator", UNSET)

        is_private = d.pop("is_private", UNSET)

        flaw_comment_post_request = cls(
            text=text,
            embargoed=embargoed,
            creator=creator,
            is_private=is_private,
        )

        flaw_comment_post_request.additional_properties = d
        return flaw_comment_post_request

    @staticmethod
    def get_fields():
        return {
            "text": str,
            "embargoed": bool,
            "creator": str,
            "is_private": bool,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from .osidb_api_v1_affects_bulk_create import *
from .osidb_api_v1_affects_bulk_destroy import *
from .osidb_api_v1_affects_bulk_update import *
from .osidb_api_v1_affects_create import *
from .osidb_api_v1_affects_cvss_scores_create import *
from .osidb_api_v1_affects_cvss_scores_destroy import *
from .osidb_api_v1_affects_cvss_scores_list import *
from .osidb_api_v1_affects_cvss_scores_retrieve import *
from .osidb_api_v1_affects_cvss_scores_update import *
from .osidb_api_v1_affects_destroy import *
from .osidb_api_v1_affects_list import *
from .osidb_api_v1_affects_retrieve import *
from .osidb_api_v1_affects_update import *
from .osidb_api_v1_alerts_list import *
from .osidb_api_v1_alerts_retrieve import *
from .osidb_api_v1_audit_list import *
from .osidb_api_v1_audit_retrieve import *
from .osidb_api_v1_audit_update import *
from .osidb_api_v1_flaws_acknowledgments_create import *
from .osidb_api_v1_flaws_acknowledgments_destroy import *
from .osidb_api_v1_flaws_acknowledgments_list import *
from .osidb_api_v1_flaws_acknowledgments_retrieve import *
from .osidb_api_v1_flaws_acknowledgments_update import *
from .osidb_api_v1_flaws_comments_create import *
from .osidb_api_v1_flaws_comments_list import *
from .osidb_api_v1_flaws_comments_retrieve import *
from .osidb_api_v1_flaws_create import *
from .osidb_api_v1_flaws_cvss_scores_create import *
from .osidb_api_v1_flaws_cvss_scores_destroy import *
from .osidb_api_v1_flaws_cvss_scores_list import *
from .osidb_api_v1_flaws_cvss_scores_retrieve import *
from .osidb_api_v1_flaws_cvss_scores_update import *
from .osidb_api_v1_flaws_labels_create import *
from .osidb_api_v1_flaws_labels_destroy import *
from .osidb_api_v1_flaws_labels_list import *
from .osidb_api_v1_flaws_labels_retrieve import *
from .osidb_api_v1_flaws_labels_update import *
from .osidb_api_v1_flaws_list import *
from .osidb_api_v1_flaws_package_versions_create import *
from .osidb_api_v1_flaws_package_versions_destroy import *
from .osidb_api_v1_flaws_package_versions_list import *
from .osidb_api_v1_flaws_package_versions_retrieve import *
from .osidb_api_v1_flaws_package_versions_update import *
from .osidb_api_v1_flaws_promote_create import *
from .osidb_api_v1_flaws_references_create import *
from .osidb_api_v1_flaws_references_destroy import *
from .osidb_api_v1_flaws_references_list import *
from .osidb_api_v1_flaws_references_retrieve import *
from .osidb_api_v1_flaws_references_update import *
from .osidb_api_v1_flaws_reject_create import *
from .osidb_api_v1_flaws_retrieve import *
from .osidb_api_v1_flaws_update import *
from .osidb_api_v1_labels_list import *
from .osidb_api_v1_labels_retrieve import *
from .osidb_api_v1_manifest_retrieve import *
from .osidb_api_v1_schema_retrieve import *
from .osidb_api_v1_status_retrieve import *
from .osidb_api_v1_trackers_create import *
from .osidb_api_v1_trackers_list import *
from .osidb_api_v1_trackers_retrieve import *
from .osidb_api_v1_trackers_update import *
from .osidb_healthy_retrieve import *
from .osidb_whoami_retrieve import *



import datetime
from typing import Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.alert_type_enum import AlertTypeEnum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="OsidbApiV1AlertsRetrieveResponse200")


@_attrs_define
class OsidbApiV1AlertsRetrieveResponse200(OSIDBModel):
    """
    Attributes:
        uuid (UUID):
        name (str):
        description (str):
        parent_uuid (UUID):
        parent_model (str):
        alert_type (Union[Unset, AlertTypeEnum]):
        resolution_steps (Union[Unset, str]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    uuid: UUID
    name: str
    description: str
    parent_uuid: UUID
    parent_model: str
    alert_type: Union[Unset, AlertTypeEnum] = UNSET
    resolution_steps: Union[Unset, str] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        uuid: str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        name = self.name

        description = self.description

        parent_uuid: str = UNSET
        if not isinstance(self.parent_uuid, Unset):
            parent_uuid = str(self.parent_uuid)

        parent_model = self.parent_model

        alert_type: Union[Unset, str] = UNSET
        if not isinstance(self.alert_type, Unset):
            alert_type = AlertTypeEnum(self.alert_type).value

        resolution_steps = self.resolution_steps

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(uuid, Unset):
            field_dict["uuid"] = uuid
        if not isinstance(name, Unset):
            field_dict["name"] = name
        if not isinstance(description, Unset):
            field_dict["description"] = description
        if not isinstance(parent_uuid, Unset):
            field_dict["parent_uuid"] = parent_uuid
        if not isinstance(parent_model, Unset):
            field_dict["parent_model"] = parent_model
        if not isinstance(alert_type, Unset):
            field_dict["alert_type"] = alert_type
        if not isinstance(resolution_steps, Unset):
            field_dict["resolution_steps"] = resolution_steps
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        _uuid = d.pop("uuid", UNSET)
        uuid: UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = _uuid if isinstance(_uuid, UUID) else UUID(_uuid)

        name = d.pop("name", UNSET)

        description = d.pop("description", UNSET)

        _parent_uuid = d.pop("parent_uuid", UNSET)
        parent_uuid: UUID
        if isinstance(_parent_uuid, Unset):
            parent_uuid = UNSET
        else:
            parent_uuid = (
                _parent_uuid if isinstance(_parent_uuid, UUID) else UUID(_parent_uuid)
            )

        parent_model = d.pop("parent_model", UNSET)

        _alert_type = d.pop("alert_type", UNSET)
        alert_type: Union[Unset, AlertTypeEnum]
        if isinstance(_alert_type, Unset):
            alert_type = UNSET
        else:
            alert_type = AlertTypeEnum(_alert_type)

        resolution_steps = d.pop("resolution_steps", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_alerts_retrieve_response_200 = cls(
            uuid=uuid,
            name=name,
            description=description,
            parent_uuid=parent_uuid,
            parent_model=parent_model,
            alert_type=alert_type,
            resolution_steps=resolution_steps,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v1_alerts_retrieve_response_200.additional_properties = d
        return osidb_api_v1_alerts_retrieve_response_200

    @staticmethod
    def get_fields():
        return {
            "uuid": UUID,
            "name": str,
            "description": str,
            "parent_uuid": UUID,
            "parent_model": str,
            "alert_type": AlertTypeEnum,
            "resolution_steps": str,
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, OSIDBModel, Unset

if TYPE_CHECKING:
    from ..models.alert import Alert


T = TypeVar("T", bound="PaginatedAlertList")


@_attrs_define
class PaginatedAlertList(OSIDBModel):
    """
    Attributes:
        count (int):  Example: 123.
        results (list['Alert']):
        next_ (Union[None, Unset, str]):  Example: http://api.example.org/accounts/?offset=400&limit=100.
        previous (Union[None, Unset, str]):  Example: http://api.example.org/accounts/?offset=200&limit=100.
    """

    count: int
    results: list["Alert"]
    next_: Union[None, Unset, str] = UNSET
    previous: Union[None, Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        count = self.count

        results: list[dict[str, Any]] = UNSET
        if not isinstance(self.results, Unset):
            results = []
            for results_item_data in self.results:
                results_item: dict[str, Any] = UNSET
                if not isinstance(results_item_data, Unset):
                    results_item = results_item_data.to_dict()

                results.append(results_item)

        next_: Union[None, Unset, str]
        if isinstance(self.next_, Unset):
            next_ = UNSET
        else:
            next_ = self.next_

        previous: Union[None, Unset, str]
        if isinstance(self.previous, Unset):
            previous = UNSET
        else:
            previous = self.previous

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(count, Unset):
            field_dict["count"] = count
        if not isinstance(results, Unset):
            field_dict["results"] = results
        if not isinstance(next_, Unset):
            field_dict["next"] = next_
        if not isinstance(previous, Unset):
            field_dict["previous"] = previous

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        from ..models.alert import Alert

        d = src_dict.copy()
        count = d.pop("count", UNSET)

        results = []
        _results = d.pop("results", UNSET)
        for results_item_data in _results or []:
            _results_item = results_item_data
            results_item: Alert
            if isinstance(_results_item, Unset):
                results_item = UNSET
            else:
                results_item = Alert.from_dict(_results_item)

            results.append(results_item)

        def _parse_next_(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        next_ = _parse_next_(d.pop("next", UNSET))

        def _parse_previous(data: object) -> Union[None, Unset, str]:
            if data is None:
                return data
            if isinstance(data, Unset):
                return data
            return cast(Union[None, Unset, str], data)

        previous = _parse_previous(d.pop("previous", UNSET))

        paginated_alert_list = cls(
            count=count,
            results=results,
            next_=next_,
            previous=previous,
        )

        paginated_alert_list.additional_properties = d
        return paginated_alert_list

    @staticmethod
    def get_fields():
        return {
            "count": int,
            "results": list["Alert"],
            "next": Union[None, str],
            "previous": Union[None, str],
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, TypeVar, Union
from uuid import UUID

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.state_enum import StateEnum
from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="OsidbApiV1FlawsLabelsCreateResponse201")


@_attrs_define
class OsidbApiV1FlawsLabelsCreateResponse201(OSIDBModel):
    """
    Attributes:
        uuid (UUID):
        label (str):
        type_ (str):
        state (Union[Unset, StateEnum]):
        contributor (Union[Unset, str]):
        relevant (Union[Unset, bool]):
        dt (Union[Unset, datetime.datetime]):
        env (Union[Unset, str]):
        revision (Union[Unset, str]):
        version (Union[Unset, str]):
    """

    uuid: UUID
    label: str
    type_: str
    state: Union[Unset, StateEnum] = UNSET
    contributor: Union[Unset, str] = UNSET
    relevant: Union[Unset, bool] = UNSET
    dt: Union[Unset, datetime.datetime] = UNSET
    env: Union[Unset, str] = UNSET
    revision: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        uuid: str = UNSET
        if not isinstance(self.uuid, Unset):
            uuid = str(self.uuid)

        label = self.label

        type_ = self.type_

        state: Union[Unset, str] = UNSET
        if not isinstance(self.state, Unset):
            state = StateEnum(self.state).value

        contributor = self.contributor

        relevant = self.relevant

        dt: Union[Unset, str] = UNSET
        if not isinstance(self.dt, Unset):
            dt = self.dt.isoformat()

        env = self.env

        revision = self.revision

        version = self.version

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(uuid, Unset):
            field_dict["uuid"] = uuid
        if not isinstance(label, Unset):
            field_dict["label"] = label
        if not isinstance(type_, Unset):
            field_dict["type"] = type_
        if not isinstance(state, Unset):
            field_dict["state"] = state
        if not isinstance(contributor, Unset):
            field_dict["contributor"] = contributor
        if not isinstance(relevant, Unset):
            field_dict["relevant"] = relevant
        if not isinstance(dt, Unset):
            field_dict["dt"] = dt
        if not isinstance(env, Unset):
            field_dict["env"] = env
        if not isinstance(revision, Unset):
            field_dict["revision"] = revision
        if not isinstance(version, Unset):
            field_dict["version"] = version

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        _uuid = d.pop("uuid", UNSET)
        uuid: UUID
        if isinstance(_uuid, Unset):
            uuid = UNSET
        else:
            uuid = _uuid if isinstance(_uuid, UUID) else UUID(_uuid)

        label = d.pop("label", UNSET)

        type_ = d.pop("type", UNSET)

        _state = d.pop("state", UNSET)
        state: Union[Unset, StateEnum]
        if isinstance(_state, Unset):
            state = UNSET
        else:
            state = StateEnum(_state)

        contributor = d.pop("contributor", UNSET)

        relevant = d.pop("relevant", UNSET)

        _dt = d.pop("dt", UNSET)
        dt: Union[Unset, datetime.datetime]
        if isinstance(_dt, Unset):
            dt = UNSET
        else:
            dt = isoparse(_dt)

        env = d.pop("env", UNSET)

        revision = d.pop("revision", UNSET)

        version = d.pop("version", UNSET)

        osidb_api_v1_flaws_labels_create_response_201 = cls(
            uuid=uuid,
            label=label,
            type_=type_,
            state=state,
            contributor=contributor,
            relevant=relevant,
            dt=dt,
            env=env,
            revision=revision,
            version=version,
        )

        osidb_api_v1_flaws_labels_create_response_201.additional_properties = d
        return osidb_api_v1_flaws_labels_create_response_201

    @staticmethod
    def get_fields():
        return {
            "uuid": UUID,
            "label": str,
            "type": str,
            "state": StateEnum,
            "contributor": str,
            "relevant": bool,
            "dt": datetime.datetime,
            "env": str,
            "revision": str,
            "version": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



"""
osidb-bindings iterators
"""

import re
from functools import partial
from typing import Callable, Optional

from .constants import DEFAULT_LIMIT
from .exceptions import OSIDBBindingsException


class Paginator:
    """
    Iterator for handling API pagination.

    Receives either starting limit and offset together with the retreive list function
    or already existing response from which it should continue.

    It keeps calling `.next()` response until pages are exhausted.
    """

    def __init__(
        self,
        *args,
        retrieve_list_fn: Optional[Callable] = None,
        limit: int = DEFAULT_LIMIT,
        offset: int = 0,
        init_response=None,
        **kwargs,
    ):
        if not init_response and not retrieve_list_fn:
            raise OSIDBBindingsException(
                (
                    "Paginator needs either initial response or session"
                    "operation function to obtain the initial response."
                )
            )

        self.retrieve_list_fn = retrieve_list_fn

        # initial starting data
        self.__init_limit = limit
        self.__init_offset = offset
        self.__init_response = init_response

        # current response page
        self.current_response = init_response

        # request arguments
        self.args = args
        self.kwargs = kwargs

    def __iter__(self):
        # restore initial response
        self.current_response = self.__init_response
        return self

    def __next__(self):
        if self.current_response is None:
            # no current response page - obtain the first page
            response = self.retrieve_list_fn(
                *self.args,
                limit=self.__init_limit,
                offset=self.__init_offset,
                **self.kwargs,
            )
            response = self.make_response_iterable(
                response, self.retrieve_list_fn, *self.args, **self.kwargs
            )
            self.current_response = response
            return response
        else:
            # existing current response - call next page
            response = self.current_response.next()
            if response is not None:
                self.current_response = response
                return response
            else:
                raise StopIteration

    @staticmethod
    def make_response_iterable(response, retrieve_list_fn, *args, **kwargs):
        """
        Populate next, prev and iterator helper methods for paginated responses
        """

        response.iterator = Paginator(
            init_response=response,
        )

        for param_name, func_name in (("next_", "next"), ("previous", "prev")):
            kwargs.pop("limit", None)
            kwargs.pop("offset", None)
            param = getattr(response, param_name, None)
            if param is None:
                setattr(response, func_name, lambda: None)
            else:
                limit = re.search(r"limit=(\d+)", param)
                if limit is not None:
                    kwargs["limit"] = limit.group(1)
                offset = re.search(r"offset=(\d+)", param)
                if offset is not None:
                    kwargs["offset"] = offset.group(1)

                setattr(response, func_name, partial(retrieve_list_fn, *args, **kwargs))

        return response



from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="osidb_bindings",
    version="4.10.1",
    author="Jakub Frejlach, Red Hat Product Security",
    author_email="jfrejlac@redhat.com",
    description="Python bindings for accessing OSIDB API",
    url="https://github.com/RedHatProductSecurity/osidb-bindings",
    project_urls={
        "Changelog": "https://github.com/RedHatProductSecurity/osidb-bindings/blob/master/CHANGELOG.md",
        "Documentation": "https://github.com/RedHatProductSecurity/osidb-bindings/blob/master/TUTORIAL.md",
        "Source": "https://github.com/RedHatProductSecurity/osidb-bindings",
    },
    long_description=long_description,
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
    ],
    packages=find_packages(),
    python_requires=">=3.6",
    install_requires=[
        "aiohttp",
        "attrs",
        "requests",
        "requests-gssapi",
        "python-dateutil",
    ],
)



from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, OSIDBModel, Unset

T = TypeVar("T", bound="TokenObtainPair")


@_attrs_define
class TokenObtainPair(OSIDBModel):
    """
    Attributes:
        access (str):
        refresh (str):
    """

    access: str
    refresh: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        access = self.access

        refresh = self.refresh

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        if not isinstance(access, Unset):
            field_dict["access"] = access
        if not isinstance(refresh, Unset):
            field_dict["refresh"] = refresh

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        access = d.pop("access", UNSET)

        refresh = d.pop("refresh", UNSET)

        token_obtain_pair = cls(
            access=access,
            refresh=refresh,
        )

        token_obtain_pair.additional_properties = d
        return token_obtain_pair

    @staticmethod
    def get_fields():
        return {
            "access": str,
            "refresh": str,
        }

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, Optional, Union
from uuid import UUID

import requests

from ...client import AuthenticatedClient, Client
from ...models.osidb_api_v1_affects_cvss_scores_list_issuer import (
    OsidbApiV1AffectsCvssScoresListIssuer,
)
from ...models.osidb_api_v1_affects_cvss_scores_list_response_200 import (
    OsidbApiV1AffectsCvssScoresListResponse200,
)
from ...types import UNSET, Response, Unset

QUERY_PARAMS = {
    "comment": str,
    "created_dt": datetime.datetime,
    "created_dt__date": datetime.date,
    "created_dt__date__gte": datetime.date,
    "created_dt__date__lte": datetime.date,
    "created_dt__gt": datetime.datetime,
    "created_dt__gte": datetime.datetime,
    "created_dt__lt": datetime.datetime,
    "created_dt__lte": datetime.datetime,
    "cvss_version": str,
    "exclude_fields": list[str],
    "include_fields": list[str],
    "issuer": OsidbApiV1AffectsCvssScoresListIssuer,
    "limit": int,
    "offset": int,
    "score": float,
    "updated_dt": datetime.datetime,
    "updated_dt__date": datetime.date,
    "updated_dt__date__gte": datetime.date,
    "updated_dt__date__lte": datetime.date,
    "updated_dt__gt": datetime.datetime,
    "updated_dt__gte": datetime.datetime,
    "updated_dt__lt": datetime.datetime,
    "updated_dt__lte": datetime.datetime,
    "uuid": UUID,
    "vector": str,
}


def _get_kwargs(
    affect_id: UUID,
    *,
    client: AuthenticatedClient,
    comment: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cvss_version: Union[Unset, str] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    issuer: Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    score: Union[Unset, float] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
    vector: Union[Unset, str] = UNSET,
) -> dict[str, Any]:
    headers: dict[str, Any] = client.get_headers()

    params: dict[str, Any] = {}

    params["comment"] = comment

    json_created_dt: Union[Unset, str] = UNSET
    if not isinstance(created_dt, Unset):
        json_created_dt = created_dt.isoformat()

    params["created_dt"] = json_created_dt

    json_created_dt_date: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date, Unset):
        json_created_dt_date = created_dt_date.isoformat()

    params["created_dt__date"] = json_created_dt_date

    json_created_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date_gte, Unset):
        json_created_dt_date_gte = created_dt_date_gte.isoformat()

    params["created_dt__date__gte"] = json_created_dt_date_gte

    json_created_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_date_lte, Unset):
        json_created_dt_date_lte = created_dt_date_lte.isoformat()

    params["created_dt__date__lte"] = json_created_dt_date_lte

    json_created_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(created_dt_gt, Unset):
        json_created_dt_gt = created_dt_gt.isoformat()

    params["created_dt__gt"] = json_created_dt_gt

    json_created_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_gte, Unset):
        json_created_dt_gte = created_dt_gte.isoformat()

    params["created_dt__gte"] = json_created_dt_gte

    json_created_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(created_dt_lt, Unset):
        json_created_dt_lt = created_dt_lt.isoformat()

    params["created_dt__lt"] = json_created_dt_lt

    json_created_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(created_dt_lte, Unset):
        json_created_dt_lte = created_dt_lte.isoformat()

    params["created_dt__lte"] = json_created_dt_lte

    params["cvss_version"] = cvss_version

    json_exclude_fields: Union[Unset, list[str]] = UNSET
    if not isinstance(exclude_fields, Unset):
        json_exclude_fields = exclude_fields

    params["exclude_fields"] = json_exclude_fields

    json_include_fields: Union[Unset, list[str]] = UNSET
    if not isinstance(include_fields, Unset):
        json_include_fields = include_fields

    params["include_fields"] = json_include_fields

    json_issuer: Union[Unset, str] = UNSET
    if not isinstance(issuer, Unset):
        json_issuer = OsidbApiV1AffectsCvssScoresListIssuer(issuer).value

    params["issuer"] = json_issuer

    params["limit"] = limit

    params["offset"] = offset

    params["score"] = score

    json_updated_dt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt, Unset):
        json_updated_dt = updated_dt.isoformat()

    params["updated_dt"] = json_updated_dt

    json_updated_dt_date: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date, Unset):
        json_updated_dt_date = updated_dt_date.isoformat()

    params["updated_dt__date"] = json_updated_dt_date

    json_updated_dt_date_gte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date_gte, Unset):
        json_updated_dt_date_gte = updated_dt_date_gte.isoformat()

    params["updated_dt__date__gte"] = json_updated_dt_date_gte

    json_updated_dt_date_lte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_date_lte, Unset):
        json_updated_dt_date_lte = updated_dt_date_lte.isoformat()

    params["updated_dt__date__lte"] = json_updated_dt_date_lte

    json_updated_dt_gt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_gt, Unset):
        json_updated_dt_gt = updated_dt_gt.isoformat()

    params["updated_dt__gt"] = json_updated_dt_gt

    json_updated_dt_gte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_gte, Unset):
        json_updated_dt_gte = updated_dt_gte.isoformat()

    params["updated_dt__gte"] = json_updated_dt_gte

    json_updated_dt_lt: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_lt, Unset):
        json_updated_dt_lt = updated_dt_lt.isoformat()

    params["updated_dt__lt"] = json_updated_dt_lt

    json_updated_dt_lte: Union[Unset, str] = UNSET
    if not isinstance(updated_dt_lte, Unset):
        json_updated_dt_lte = updated_dt_lte.isoformat()

    params["updated_dt__lte"] = json_updated_dt_lte

    json_uuid: Union[Unset, str] = UNSET
    if not isinstance(uuid, Unset):
        json_uuid = str(uuid)

    params["uuid"] = json_uuid

    params["vector"] = vector

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: dict[str, Any] = {
        "url": f"{client.base_url}/osidb/api/v1/affects/{affect_id}/cvss_scores".format(
            affect_id=affect_id,
        ),
        "params": params,
    }

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Optional[OsidbApiV1AffectsCvssScoresListResponse200]:
    if response.status_code == 200:
        _response_200 = response.json()
        response_200: OsidbApiV1AffectsCvssScoresListResponse200
        if isinstance(_response_200, Unset):
            response_200 = UNSET
        else:
            response_200 = OsidbApiV1AffectsCvssScoresListResponse200.from_dict(
                _response_200
            )

        return response_200


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: requests.Response
) -> Response[OsidbApiV1AffectsCvssScoresListResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    affect_id: UUID,
    *,
    client: AuthenticatedClient,
    comment: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cvss_version: Union[Unset, str] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    issuer: Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    score: Union[Unset, float] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
    vector: Union[Unset, str] = UNSET,
) -> Response[OsidbApiV1AffectsCvssScoresListResponse200]:
    """
    Args:
        affect_id (UUID):
        comment (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cvss_version (Union[Unset, str]):
        exclude_fields (Union[Unset, list[str]]):
        include_fields (Union[Unset, list[str]]):
        issuer (Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        score (Union[Unset, float]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):
        vector (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1AffectsCvssScoresListResponse200]
    """

    kwargs = _get_kwargs(
        affect_id=affect_id,
        client=client,
        comment=comment,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cvss_version=cvss_version,
        exclude_fields=exclude_fields,
        include_fields=include_fields,
        issuer=issuer,
        limit=limit,
        offset=offset,
        score=score,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
        vector=vector,
    )

    response = requests.get(
        verify=client.verify_ssl,
        auth=client.auth,
        timeout=client.timeout,
        **kwargs,
    )
    response.raise_for_status()

    return _build_response(client=client, response=response)


def sync(
    affect_id: UUID,
    *,
    client: AuthenticatedClient,
    comment: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cvss_version: Union[Unset, str] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    issuer: Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    score: Union[Unset, float] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
    vector: Union[Unset, str] = UNSET,
) -> Optional[OsidbApiV1AffectsCvssScoresListResponse200]:
    """
    Args:
        affect_id (UUID):
        comment (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cvss_version (Union[Unset, str]):
        exclude_fields (Union[Unset, list[str]]):
        include_fields (Union[Unset, list[str]]):
        issuer (Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        score (Union[Unset, float]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):
        vector (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1AffectsCvssScoresListResponse200
    """

    return sync_detailed(
        affect_id=affect_id,
        client=client,
        comment=comment,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cvss_version=cvss_version,
        exclude_fields=exclude_fields,
        include_fields=include_fields,
        issuer=issuer,
        limit=limit,
        offset=offset,
        score=score,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
        vector=vector,
    ).parsed


async def asyncio_detailed(
    affect_id: UUID,
    *,
    client: AuthenticatedClient,
    comment: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cvss_version: Union[Unset, str] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    issuer: Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    score: Union[Unset, float] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
    vector: Union[Unset, str] = UNSET,
) -> Response[OsidbApiV1AffectsCvssScoresListResponse200]:
    """
    Args:
        affect_id (UUID):
        comment (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cvss_version (Union[Unset, str]):
        exclude_fields (Union[Unset, list[str]]):
        include_fields (Union[Unset, list[str]]):
        issuer (Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        score (Union[Unset, float]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):
        vector (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[OsidbApiV1AffectsCvssScoresListResponse200]
    """

    kwargs = _get_kwargs(
        affect_id=affect_id,
        client=client,
        comment=comment,
        created_dt=created_dt,
        created_dt_date=created_dt_date,
        created_dt_date_gte=created_dt_date_gte,
        created_dt_date_lte=created_dt_date_lte,
        created_dt_gt=created_dt_gt,
        created_dt_gte=created_dt_gte,
        created_dt_lt=created_dt_lt,
        created_dt_lte=created_dt_lte,
        cvss_version=cvss_version,
        exclude_fields=exclude_fields,
        include_fields=include_fields,
        issuer=issuer,
        limit=limit,
        offset=offset,
        score=score,
        updated_dt=updated_dt,
        updated_dt_date=updated_dt_date,
        updated_dt_date_gte=updated_dt_date_gte,
        updated_dt_date_lte=updated_dt_date_lte,
        updated_dt_gt=updated_dt_gt,
        updated_dt_gte=updated_dt_gte,
        updated_dt_lt=updated_dt_lt,
        updated_dt_lte=updated_dt_lte,
        uuid=uuid,
        vector=vector,
    )

    async with client.get_async_session().get(
        verify_ssl=client.verify_ssl, raise_for_status=True, **kwargs
    ) as response:
        content = await response.read()
        resp = requests.Response()
        resp.status_code = response.status
        resp._content = content

    return _build_response(client=client, response=resp)


async def asyncio(
    affect_id: UUID,
    *,
    client: AuthenticatedClient,
    comment: Union[Unset, str] = UNSET,
    created_dt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_date: Union[Unset, datetime.date] = UNSET,
    created_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    created_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    created_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    created_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    cvss_version: Union[Unset, str] = UNSET,
    exclude_fields: Union[Unset, list[str]] = UNSET,
    include_fields: Union[Unset, list[str]] = UNSET,
    issuer: Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer] = UNSET,
    limit: Union[Unset, int] = UNSET,
    offset: Union[Unset, int] = UNSET,
    score: Union[Unset, float] = UNSET,
    updated_dt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_date: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_gte: Union[Unset, datetime.date] = UNSET,
    updated_dt_date_lte: Union[Unset, datetime.date] = UNSET,
    updated_dt_gt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_gte: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lt: Union[Unset, datetime.datetime] = UNSET,
    updated_dt_lte: Union[Unset, datetime.datetime] = UNSET,
    uuid: Union[Unset, UUID] = UNSET,
    vector: Union[Unset, str] = UNSET,
) -> Optional[OsidbApiV1AffectsCvssScoresListResponse200]:
    """
    Args:
        affect_id (UUID):
        comment (Union[Unset, str]):
        created_dt (Union[Unset, datetime.datetime]):
        created_dt_date (Union[Unset, datetime.date]):
        created_dt_date_gte (Union[Unset, datetime.date]):
        created_dt_date_lte (Union[Unset, datetime.date]):
        created_dt_gt (Union[Unset, datetime.datetime]):
        created_dt_gte (Union[Unset, datetime.datetime]):
        created_dt_lt (Union[Unset, datetime.datetime]):
        created_dt_lte (Union[Unset, datetime.datetime]):
        cvss_version (Union[Unset, str]):
        exclude_fields (Union[Unset, list[str]]):
        include_fields (Union[Unset, list[str]]):
        issuer (Union[Unset, OsidbApiV1AffectsCvssScoresListIssuer]):
        limit (Union[Unset, int]):
        offset (Union[Unset, int]):
        score (Union[Unset, float]):
        updated_dt (Union[Unset, datetime.datetime]):
        updated_dt_date (Union[Unset, datetime.date]):
        updated_dt_date_gte (Union[Unset, datetime.date]):
        updated_dt_date_lte (Union[Unset, datetime.date]):
        updated_dt_gt (Union[Unset, datetime.datetime]):
        updated_dt_gte (Union[Unset, datetime.datetime]):
        updated_dt_lt (Union[Unset, datetime.datetime]):
        updated_dt_lte (Union[Unset, datetime.datetime]):
        uuid (Union[Unset, UUID]):
        vector (Union[Unset, str]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        OsidbApiV1AffectsCvssScoresListResponse200
    """

    return (
        await asyncio_detailed(
            affect_id=affect_id,
            client=client,
            comment=comment,
            created_dt=created_dt,
            created_dt_date=created_dt_date,
            created_dt_date_gte=created_dt_date_gte,
            created_dt_date_lte=created_dt_date_lte,
            created_dt_gt=created_dt_gt,
            created_dt_gte=created_dt_gte,
            created_dt_lt=created_dt_lt,
            created_dt_lte=created_dt_lte,
            cvss_version=cvss_version,
            exclude_fields=exclude_fields,
            include_fields=include_fields,
            issuer=issuer,
            limit=limit,
            offset=offset,
            score=score,
            updated_dt=updated_dt,
            updated_dt_date=updated_dt_date,
            updated_dt_date_gte=updated_dt_date_gte,
            updated_dt_date_lte=updated_dt_date_lte,
            updated_dt_gt=updated_dt_gt,
            updated_dt_gte=updated_dt_gte,
            updated_dt_lt=updated_dt_lt,
            updated_dt_lte=updated_dt_lte,
            uuid=uuid,
            vector=vector,
        )
    ).parsed
